%Estimation of State Capacity Spillovers: ADDING CONTEXTUAL EFFECTS
%Acemoglu, Garcia-Jimeno, Robinson

clear all
close all
clc

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Import data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Open data file State_Capacity_Network_Work.mat
load State_Capacity_Network_Work.mat

%%
%OPTIONS

%1: Choose Outcome variable:
 out = 4;           %1 = Secondary enrollment 92-02
                    %2 = Services Coverage 1998
                    %3 = Not in poverty 2005
                    %4 = Life Quality Index
                    
%2: Choose Measure of State Capacity:
 a_or_b = 0;        %0 = State municipality agencies 
                    %1 = State municipality bureaucracies
                    %2 = health agencies
                    %3 = regulation agencies
                    %4 = public services agencies
                    %5 = education agencies
                                    
%3: Choose if control for national-level bureaucracy 
 nat_bur=0;         %0 = no 
                    %1 = yes                    
                    
%4: Choose if control for rivers density and land shares
 river_land=0;      %0=no
                    %1=yes

%5: Choose if control for distance to current road
current_road=1;     %0=no
                    %1=yes
                    
%6: Choose assumption on Network Links
 ass_network_structure=0;       %0 = Network link is neighbors           
                                %1 = Network link is neighbors and neighbors of neighbors 
                                %2 = Network is fully connected

%7: Choose order of instruments: 
 order=3;           %1 = Instruments are Nc    
                    %2 = Instruments are N2c
                    %3 = Instruments are N3c 

%8: Choose the subset of Instruments to use:
 instruments=0;     %0 = All
                    %1 = Exclude Colonial State
                    %2 = Exclude Royal Roads

%9: Choose if exclude violent municipalities
excl_viol=0;        %0 = Do not exclude
                    %1 = Exclude from sample
                    %2 = Exclude from network

%10: Choose how to treat population
pop_treat=0;        %0=Instrument for Population with Historical Population
                    %1=Control for Population

%11: Historical Prosperity Sample
hist_prosp=0;       %0=Not restricting to 1918 Census Sample
                    %1=Restricting to 1918 Census Sample
                    
%%

 %Choose the endogenous and exogenous variables for the model
   if out==1
         Yg_input = (Yg(:,2));                                                    %Yg = Development Outcome
     else if out==2
         Yg_input = (Yg(:,4)+Yg(:,5)+Yg(:,6))/3;
         else if out==3
                 Yg_input = Yg(:,9);
             else
                 Yg_input = Yg(:,10);
             end
         end
   end

   if hist_prosp==1
        Yg_input = [(Yg(:,2)) YH];
   end
       
 
     %Chose if state capacity is agencies or bureaucracies
     
     if a_or_b == 0
         S_input = S(:,6)+S(:,7)+S(:,8)+S(:,11)+S(:,12)+S(:,13)+S(:,14)+S(:,15)+S(:,16)+S(:,18)+S(:,19);                 %S = Contemporary State
     else if a_or_b == 1
             S_input = S(:,1);
         else if a_or_b == 2
                 S_input = S(:,11)+S(:,12);
             else if a_or_b == 3
                     S_input = S(:,6)+S(:,16)+S(:,18)+S(:,19);
                 else if a_or_b == 4
                         S_input = S(:,7)+S(:,8)+S(:,15);
                     else if a_or_b == 5
                             S_input = S(:,13)+S(:,14);
                         end
                     end
                 end
             end
         end
     end
     
         
     C_input = [C(:,1) C(:,3)];                                               %C = Colonial State
     R_input = R;                                                             %R = Distance to royal roads
     
     %Choose controls
     if nat_bur==0 && river_land==0 && current_road==0                        %X = Controls
         X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5)];
        else if nat_bur==0 && river_land==0 && current_road==1
                X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) Xs(:,1)];               
            else if nat_bur==0 && river_land==1 && current_road==0
                    X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) G(:,6:8) L(:,1:7) L(:,12:15)];
                else if nat_bur==0 && river_land==1 && current_road==1
                        X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) Xs(:,1) G(:,6:8) L(:,1:7) L(:,12:15)];
                    else if nat_bur==1 && river_land==0 && current_road==0
                            X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) log(1+S(:,2))];
                        else if nat_bur==1 && river_land==0 && current_road==1
                                X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) Xs(:,1) log(1+S(:,2))];
                            else if nat_bur==1 && river_land==1 && current_road==0
                                    X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) G(:,6:8) L(:,1:7) L(:,12:15) log(1+S(:,2))];
                                else 
                                    X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) Xs(:,1) G(:,6:8) L(:,1:7) L(:,12:15) log(1+S(:,2))];
                                end
                            end
                        end
                    end
                end
            end
     end        
     
     if a_or_b == 2
         X_input = [X_input (S(:,6)+S(:,7)+S(:,8)+S(:,13)+S(:,14)+S(:,15)+S(:,16)+S(:,18)+S(:,19))];
     else if a_or_b == 3
             X_input = [X_input (S(:,7)+S(:,8)+S(:,11)+S(:,12)+S(:,13)+S(:,14)+S(:,15))];
         else if a_or_b == 4
                 X_input = [X_input (S(:,6)+S(:,11)+S(:,12)+S(:,13)+S(:,14)+S(:,16)+S(:,18)+S(:,19))];
             else if a_or_b == 5
                     X_input = [X_input (S(:,6)+S(:,7)+S(:,8)+S(:,11)+S(:,12)+S(:,15)+S(:,16)+S(:,18)+S(:,19))];
                 end
             end
         end
     end
     
     X_input = [X_input H(:,8)./1000 H(:,9)];                                 %To add 1843 population and missing pop dummy
     
     %Ev_input = Ev;                                                          %Historical Electoral variability
     A_input = Adj;                                                           %A = Adjacency matrix
     Dd_input = Ddist;                                                        %Original Distances matrix
     Drr_input = Drankrange;                                                  %Original Range of elevation ranks along path matrix
     Drv_input = Drankvar;                                                    %Original Variance of elevation ranks along path matrix
     Yv_input = Yv(:,16);                                                     %Original Per capita attacks
     
     %Clean data from missing values
     [Yg_clean S_clean C_clean X_clean R_clean Yv_clean A_clean Dd_clean Drr_clean Drv_clean DaneCodes_clean] = clean_missings(Yg_input, S_input, C_input, X_input, R_input, Yv_input, A_input, Dd_input, Drr_input, Drv_input, DaneCodes);

 clear Adj C DD Dc Ddist Drankrange Drankvar G H L R S Xs Yg Yv Ygini Ev DaneCodes
 clear Yg_input S_input C_input X_input R_input Yv_input Ev_input A_input Dd_input Drr_input Drv_input


 global p s c r
 if hist_prosp==0
     p = Yg_clean;                          %p=vector of prosperity
 else
     p = Yg_clean(:,1);
 end
 
 s= log(1+S_clean);                     %s=vector of state capacity  
 c = (C_clean);                         %c=vector of colonial state presence
 r = zscore(R_clean);                   %r=vector of distance to royal roads
 
 global D E
 D= Dd_clean;                           %D=distance matrix
 E= Drv_clean;                          %E=variance elevation matrix

 global X X_d pop hpop
    
 if a_or_b== 0 || a_or_b == 1
     X = X_clean(:,28:end-2);                %matrix of controls
 else
     X = X_clean(:,28:end-3);
     s_C = X_clean(:,end-2);                  %Complement agencies
 end
 
    hpop = X_clean(:,end-1:end);            %Matrix of 1843 population and missing 1843 population dummy
    X_d = X_clean(:,2:27);                  %matrix of department dummies and department capital dummy
    pop = X_clean(:,1)./1000;               %vector of population
 
 global A
 A=A_clean;                             %A=adjacency matrix (nxn) with 0s on the diagonal

 global n k ndep
 n=size(p,1);                           %number of observations
 k=size(X,2);                           %number of covariates
 ndep=size(X_d,2);                      %number of department dummies
 
 DaneCodes=DaneCodes_clean;             %Municipality codes to keep track
 
 %Create Indicator of violent municipalities (above 90th percentile of attacks)
 v=zeros(n,1);
 pc90 = prctile(Yv_clean,90);
 for j=1:n
     if Yv_clean(j,1)>=pc90
         v(j)=1;
     end
 end
 
 
 clear Yg_clean S_clean C_clean X_clean R_clean Yv_clean A_clean Dd_clean Drr_clean Drv_clean DaneCodes_clean
 
 
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Assumptions on the Network Structure
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if excl_viol==2
    p = p(~v,:);
    s = s(~v,:);
    c = c(~v,:);
    r = r(~v,:);
    X = X(~v,:);
    X_d =X_d(~v,:);
    pop = pop(~v,:);
    hpop = hpop(~v,:);
    
    D0 = D(~v,:)';
    D = (D0(~v,:))';
    
    E0 = E(~v,:)';
    E = (E0(~v,:))';
    
    A0 = A(~v,:)';
    A = (A0(~v,:))';

    clear D0 E0 A0

    n=size(p,1);
end

global NE N N_2 A_2 A_3
F=1./(1+(D.*(1+E)));

%Re-sets the diagonal to zeroes
for i=1:size(F,1)
    F(i,i)=0;
end

Q=(ones(n,n)-A).*(A*A-diag(diag(A*A)));                 %Matrix of Number of Paths to Neighbors of Neighbors who are not own Neighbors
A_2=ismember(Q,1:1:max(max(Q)));                        %Adjacency Matrix of neighbors of neighbors
A_2=+A_2;                                               % from logical to numeric

Q2=(ones(n,n)-A-A_2).*((A*A*A)-diag(diag(A*A*A)));      %Matrix of Number of Paths to Neighbors of Neighbors of Neighbors who are not own Neighbors or own Neighbors of Neighbors
A_3 = ismember(Q2,1:1:max(max(Q2)));                    %Adjacency Matrix of neighbors of neighbors of neighbors
A_3=+A_3;                                               % from logical to numeric
clear Q Q2


if ass_network_structure==1 
    A=(A+A_2);                                          %Adjacency matrix when Network link is defined by assumption b
    A_2=A_3;                                            %Adjacency matrix of neighbors of neighbors when Network link is defined by assumption b    
end

%Network matrix of adjacent neighbors
NE = F.*A; 

if order==2
    N=F.*A;                                                 %Network matrix of neighbors
    N_2=F.*A_2;                                             %Network matrix of neighbors of neighbors
else if order==3
        N=F.*A_2;                                           %Network matrix of neighbors of neighbors
        N_2=F.*A_3;                                         %Network matrix of neighbors of neighbors of neighbors
    else if order==1
            N=F.*A;                                         %Network matrix of neighbors
            N_2=F.*A;                                       %Network matrix of neighbors
        end
    end
end

if ass_network_structure==2 
    NE=F;
    N=F;
    N_2=F^2;
end

%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%Best response Equation 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Linear Model
%s = f( N*s , c1 , c2 , X , X_d)
%N*s = g(N*c , N*r , N_2*c , N_2*r , X , X_d)

endog_var = NE*s;

if pop_treat==0

    if a_or_b<2
        if instruments==0
             Z =     [N*log(1+c) N*r N_2*log(1+c) N_2*r log(1+c) r zscore(X) X_d NE*log(1+c) NE*r NE*zscore(X) ones(n,1) log(hpop(:,1)) hpop(:,2)];                                                     %Benchmark
            XX =     [endog_var                         log(1+c) r zscore(X) X_d NE*log(1+c) NE*r NE*zscore(X) ones(n,1)                 log(pop)];
            
            ZZZf = [N*log(1+c) N*r N_2*log(1+c) N_2*r log(hpop(:,1)) hpop(:,2)];
            XXXf = [log(1+c) r zscore(X) X_d NE*log(1+c) NE*r NE*zscore(X) ones(n,1)];
    
        else if instruments==1
                 Z = [           N*r              N_2*r          r zscore(X) X_d NE*log(1+c) NE*r NE*zscore(X) ones(n,1) log(hpop(:,1)) hpop(:,2)];
                XX = [endog_var                                  r zscore(X) X_d NE*log(1+c) NE*r NE*zscore(X) ones(n,1)                 log(pop)];
                
                 ZZZf = [ N*r N_2*r log(hpop(:,1)) hpop(:,2)];
                 XXXf = [ r zscore(X) X_d NE*log(1+c) NE*r NE*zscore(X) ones(n,1)];
                
            else
                 Z = [N*log(1+c)     N_2*log(1+c)       log(1+c)   zscore(X) X_d ones(n,1) log(hpop(:,1)) hpop(:,2)];
                XX = [endog_var          log(1+c)                  zscore(X) X_d NE*log(1+c) NE*r NE*zscore(X) ones(n,1)                 log(pop)];
                
                ZZZf = [N*log(1+c) N_2*log(1+c) log(hpop(:,1)) hpop(:,2)];
                XXXf = [ log(1+c) zscore(X) X_d NE*log(1+c) NE*r NE*zscore(X) ones(n,1)];
            end
        end
        
    else if a_or_b>=2
            if instruments==0
                 Z = [N*log(1+c) N*r N_2*log(1+c) N_2*r             log(1+c) r zscore(X) X_d NE*log(1+c) NE*r NE*zscore(X) ones(n,1) log(hpop(:,1)) hpop(:,2)];
                XX = [endog_var                                     log(1+c) r zscore(X) X_d NE*log(1+c) NE*r NE*zscore(X) ones(n,1)                 log(pop)];
            end
        end
    end

else if pop_treat==1
        
        if a_or_b<2
            if instruments==0
                 Z =     [N*log(1+c) N*r N_2*log(1+c) N_2*r log(1+c) r zscore(X) X_d NE*log(1+c) NE*r NE*zscore(X) ones(n,1) log(pop)];                                                     %Benchmark
                XX =     [endog_var                         log(1+c) r zscore(X) X_d NE*log(1+c) NE*r NE*zscore(X) ones(n,1) log(pop)];
                
                ZZZr = [log(1+c) r zscore(X) X_d NE*log(1+c) NE*r NE*zscore(X) ones(n,1) log(pop)];
                
            else if instruments==1
                     Z = [           N*r              N_2*r          r zscore(X) X_d NE*log(1+c) NE*r NE*zscore(X) ones(n,1) log(pop)];
                    XX = [endog_var                                  r zscore(X) X_d NE*log(1+c) NE*r NE*zscore(X) ones(n,1) log(pop)];
                    
                    ZZZr = [r zscore(X) X_d ones(n,1) log(pop)];
                else
                     Z = [N*log(1+c)     N_2*log(1+c)       log(1+c)   zscore(X) X_d NE*log(1+c) NE*r NE*zscore(X) ones(n,1) log(pop)];
                    XX = [endog_var          log(1+c)                  zscore(X) X_d NE*log(1+c) NE*r NE*zscore(X) ones(n,1) log(pop)];
                    
                    ZZZr = [log(1+c) zscore(X) X_d NE*log(1+c) NE*r NE*zscore(X) ones(n,1) log(pop)];
                end
            end
            
        else if a_or_b>=2
                if instruments==0
                     Z = [N*log(1+c) N*r N_2*log(1+c) N_2*r             log(1+c) r zscore(X) X_d NE*log(1+c) NE*r NE*zscore(X) ones(n,1) log(pop)];
                    XX = [endog_var                        	            log(1+c) r zscore(X) X_d NE*log(1+c) NE*r NE*zscore(X) ones(n,1) log(pop)];
                end
            end
        end
    end
end      

YY = s;

    if excl_viol==1
        Z = Z(~v,:);
        XX = XX(~v,:);
        YY = YY(~v,:);
        n = size(YY,1);
        
        if pop_treat==0 & a_or_b<2
            ZZZf = ZZZf(~v,:);
            XXXf = XXXf(~v,:);
        else if pop_treat==1 & a_or_b<2
                ZZZr = ZZZr(~v,:);
            end
        end
    end

 %Marginal Effects
    Avg_nij = N(:);
    Avg_nij = mean(Avg_nij(Avg_nij~=0));    

    
%OLS
coeff_OLS_BR = (XX'*XX)\(XX'*YY);
disp('coefficients estimates best response OLS')
disp([coeff_OLS_BR(1:6)]')

    % standard errors
    resid=YY-XX*coeff_OLS_BR;
    % construction of the variance of the coefficients estimators
    inside_part=0;
    for i=1:n
        inside_part=(resid(i))^2*XX(i,:)'*XX(i,:) + inside_part;               
    end
    var_coeff_OLS_BR=((XX'*XX)\(inside_part)/(XX'*XX));
    std_error_OLS_BR=sqrt(diag(var_coeff_OLS_BR));                                            % standard errors
    disp('standard errors for Best response OLS')
    disp([std_error_OLS_BR(1:6)]')
  
    %Spatial correlation-corrected standard errors
    OMEG=resid*resid';
    VU = (OMEG.*eye(n)) + ((2/3)*((OMEG.*N)+(OMEG.*N)')) + ((1/3)*((OMEG.*N_2)+(OMEG.*N_2)'));
    var_coeff_OLS_BR_Spatial = (XX'*XX)\XX'*VU*XX/(XX'*XX);
    std_error_OLS_BR_Spatial = sqrt(diag(var_coeff_OLS_BR_Spatial)); 
    
    disp('spatial standard errors for Best response OLS')
    disp([std_error_OLS_BR_Spatial(1:6)]')
    
    if ass_network_structure<2
        disp('ds_i/ds_j OLS')
        disp(Avg_nij*coeff_OLS_BR(1))
        disp('standard error OLS')
        disp(Avg_nij*std_error_OLS_BR(1))
        disp('spatial standard error OLS')
        disp(Avg_nij*std_error_OLS_BR_Spatial(1))
    else if ass_network_structure==2
        disp('ds_i/ds_j OLS')
        disp((n/5)*Avg_nij*coeff_OLS_BR(1))
        disp('standard error OLS')
        disp((n/5)*Avg_nij*std_error_OLS_BR(1))
        disp('spatial standard error OLS')
        disp((n/5)*Avg_nij*std_error_OLS_BR_Spatial(1))
        end
    end
    
%IV
Q= XX'*Z*(inv(Z'*Z))*Z';
coeff_IV_BR=(Q*XX)\(Q*YY);             % estimation of the coefficients

ppsi1=coeff_IV_BR(1);
phi=coeff_IV_BR(2:4);
bbeta=coeff_IV_BR(5:end);
disp('coefficients estimates best response IV')
disp([coeff_IV_BR(1:6)]')

    % standard errors
    resid=YY-XX*coeff_IV_BR;
    % construction of the variance of the coefficients estimators
    inside_part=0;
    for i=1:n
        inside_part=(resid(i))^2*Z(i,:)'*Z(i,:) + inside_part;               
    end
    var_coeff_IV_BR=((Q*XX)\(XX'*Z*(inv(Z'*Z)))*inside_part*((inv(Z'*Z))*Z'*XX)/(Q*XX));
    std_error_IV_BR=sqrt(diag(var_coeff_IV_BR));                                            % standard errors
    disp('standard errors for Best response IV')
    disp([std_error_IV_BR(1:6)]')

    %Spatial correlation-corrected standard errors
    OMEG= resid*resid';
    VU = (OMEG.*eye(n)) + ((2/3)*((OMEG.*N)+(OMEG.*N)')) + ((1/3)*((OMEG.*N_2)+(OMEG.*N_2)'));
    var_coeff_IV_BR_Spatial = (Q*XX)\Q*VU*Q'/(Q*XX);
    std_error_IV_BR_Spatial = sqrt(diag(var_coeff_IV_BR_Spatial)); 
    disp('spatial standard errors for Best response IV')
    disp([std_error_IV_BR_Spatial(1:6)]')
    
    
    %Overid Test: OID ~ Chi-squared(degree of overid)
    num_overid = size(Z,2)-size(XX,2);
    OID = (resid'*(Z*(inv(Z'*Z))*Z')*resid)/(resid'*resid/(n-k-ndep));
    
    disp('OID statistic p-value for the OID Test')
    disp([OID 1-chi2cdf(OID,num_overid)])
    
    if ass_network_structure<2
        disp('ds_i/ds_j IV')
        disp(Avg_nij*coeff_IV_BR(1))
        disp('standard error IV')
        disp(Avg_nij*std_error_IV_BR(1))
        disp('spatial standard error IV')
        disp(Avg_nij*std_error_IV_BR_Spatial(1))
    else if ass_network_structure==2
        disp('ds_i/ds_j IV')
        disp((n/5)*Avg_nij*coeff_IV_BR(1))
        disp('standard error IV')
        disp((n/5)*Avg_nij*std_error_IV_BR(1))
        disp('spatial standard error IV')
        disp((n/5)*Avg_nij*std_error_IV_BR_Spatial(1))
        end
    end
    
    %First Stage
    coeff_1st_stage_BR = (Z'*Z)\(Z'*XX(:,1));
    disp('coefficients estimates First Stage best response')
    disp([coeff_1st_stage_BR(1:6)]')
    
    % standard errors
    resid=XX(:,1) - Z*coeff_1st_stage_BR;
    % construction of the variance of the coefficients estimators
    inside_part=0;
    for i=1:n
        inside_part=(resid(i))^2*Z(i,:)'*Z(i,:) + inside_part;               
    end
    var_coeff_1st_stage_BR=((Z'*Z)\(inside_part)/(Z'*Z));
    std_error_1st_stage_BR=sqrt(diag(var_coeff_1st_stage_BR));                                            % standard errors
    disp('standard errors for 1st Stage Best response')
    disp([std_error_1st_stage_BR(1:6)]')
    
    %Spatial correlation-corrected standard errors
    OMEG= resid*resid';
    VU = (OMEG.*eye(n)) + ((2/3)*((OMEG.*N)+(OMEG.*N)')) + ((1/3)*((OMEG.*N_2)+(OMEG.*N_2)'));
    var_coeff_1st_stage_BR_spatial =(Z'*Z)\Z'*VU*Z/(Z'*Z);
    std_error_1st_stage_BR_spatial=sqrt(diag(var_coeff_1st_stage_BR_spatial));                                            % standard errors
    disp('spatial standard errors for 1st Stage Best response')
    disp([std_error_1st_stage_BR_spatial(1:6)]')
    
    R_sq_BR = 1 - ((sum(resid.*resid)/sum(((XX(:,1) - (sum(XX(:,1))/n)).^2))));
    disp('R squared First Stage')
    disp(R_sq_BR)
 
    
    
    if pop_treat==0 && a_or_b<2
            %Modified F-statistic (multiple endogenous regressors: Angrist-Pischke (2009))
            XXXf = [Z*((Z'*Z)\(Z'*XX(:,end))) XXXf];
            res_for_f = XX(:,1) - XXXf*((XXXf'*XXXf)\(XXXf'*XX(:,1)));

            coef_for_f =  (ZZZf'*ZZZf)\(ZZZf'*res_for_f);
    
            SSRr  = sum( (res_for_f - ones(n,1)*((ones(n,1)'*ones(n,1))\(ones(n,1)'*res_for_f)) ).^2);
            SSRur = sum( (res_for_f - ZZZf*coef_for_f).^2 );
    
            F_test = ((n-size(ZZZf,2))/size(ones(n,1),2))*(SSRr - SSRur)/SSRur;
            disp('F test for excluded instruments')
            disp('F-stat')
            disp(F_test)
            disp('p-value')
            disp(1-fcdf(F_test,size(ones(n,1),2),(n-size(ZZZf,2))))
    
    else if pop_treat==1 && a_or_b<2
            %Usual F-statistic
            cr=(ZZZr'*ZZZr)\(ZZZr'*XX(:,1));
            SSRr  = sum( (XX(:,1) - ZZZr*cr).^2 );
            SSRur = sum(resid.*resid);
            
            F_test = ((n-size(Z,2))/size(ZZZr,2))*(SSRr - SSRur)/SSRur;
            disp('F test for excluded instruments')
            disp('F-stat')
            disp(F_test)
            disp('p-value')
            disp(1-fcdf(F_test,size(ZZZr,2),(n-size(Z,2))))
            
        end
    end
           
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%Outcomes Equation
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    

%Structural Equation
disp('structural')
    
if pop_treat==0
    XXXf = [zscore(X) NE*zscore(X) X_d]; 
    if instruments==0
        Z = [N*log(1+c) N*r (N*log(1+c)).^2 (N*r).^2 (N*log(1+c)).^3 (N*r).^3 (N*log(1+c)).^4 (N*r).^4 N_2*log(1+c) N_2*r (N_2*log(1+c)).^2 (N_2*r).^2 (N_2*log(1+c)).^3 (N_2*r).^3 (N_2*log(1+c)).^4 (N_2*r).^4 zscore(X) NE*zscore(X) X_d hpop];
        
        ZZZf = [N*log(1+c) N*r (N*log(1+c)).^2 (N*r).^2 (N*log(1+c)).^3 (N*r).^3 (N*log(1+c)).^4 (N*r).^4 N_2*log(1+c) N_2*r (N_2*log(1+c)).^2 (N_2*r).^2 (N_2*log(1+c)).^3 (N_2*r).^3 (N_2*log(1+c)).^4 (N_2*r).^4 hpop];
    else if instruments==1
            Z = [N*log(1+c(:,2)) N*r (N*log(1+c(:,2))).^2 (N*r).^2 (N*log(1+c(:,2))).^3 (N*r).^3 (N*log(1+c(:,2))).^4 (N*r).^4 N_2*log(1+c(:,2)) N_2*r (N_2*log(1+c(:,2))).^2 (N_2*r).^2  zscore(X) NE*zscore(X) X_d hpop];
            
            ZZZf = [N*log(1+c(:,2)) N*r (N*log(1+c(:,2))).^2 (N*r).^2 (N*log(1+c(:,2))).^3 (N*r).^3 (N*log(1+c(:,2))).^4 (N*r).^4 N_2*log(1+c(:,2)) N_2*r (N_2*log(1+c(:,2))).^2 (N_2*r).^2 hpop];
        else if instruments==2
            Z = [N*log(1+c) (N*log(1+c)).^2 (N*log(1+c)).^3 (N*log(1+c)).^4 N_2*log(1+c) (N_2*log(1+c)).^2 (N_2*log(1+c)).^3 (N_2*log(1+c)).^4 zscore(X) NE*zscore(X) X_d hpop];
            
            ZZZf = [N*log(1+c) (N*log(1+c)).^2 (N*log(1+c)).^3 (N*log(1+c)).^4 N_2*log(1+c) (N_2*log(1+c)).^2 (N_2*log(1+c)).^3 (N_2*log(1+c)).^4 hpop];
            else if instruments==3
                Z = [N*r (N*r).^2 (N*r).^3 (N*r).^4 N_2*r (N_2*r).^2 (N_2*r).^3 (N_2*r).^4 zscore(X) NE*zscore(X) X_d hpop];
        
                ZZZf = [N*r (N*r).^2 (N*r).^3 (N*r).^4 N_2*r (N_2*r).^2 (N_2*r).^3 (N_2*r).^4 hpop];
                else if instruments==4
                        Z = [N*log(1+c(:,1)) (N*log(1+c(:,1))).^2 (N*log(1+c(:,1))).^3 (N*log(1+c(:,1))).^4 N_2*log(1+c(:,1)) (N_2*log(1+c(:,1))).^2 (N_2*log(1+c(:,1))).^3 (N_2*log(1+c(:,1))).^4 zscore(X) NE*zscore(X) X_d hpop];
        
                        ZZZf = [N*log(1+c(:,1)) (N*log(1+c(:,1))).^2 (N*log(1+c(:,1))).^3 (N*log(1+c(:,1))).^4 N_2*log(1+c(:,1)) (N_2*log(1+c(:,1))).^2 (N_2*log(1+c(:,1))).^3 (N_2*log(1+c(:,1))).^4 hpop];
                    else 
                        Z = [N*log(1+c(:,2)) (N*log(1+c(:,2))).^2 (N*log(1+c(:,2))).^3 (N*log(1+c(:,2))).^4 N_2*log(1+c(:,2)) (N_2*log(1+c(:,2))).^2 (N_2*log(1+c(:,2))).^3 (N_2*log(1+c(:,2))).^4 zscore(X) NE*zscore(X) X_d hpop];
        
                        ZZZf = [N*log(1+c(:,2)) (N*log(1+c(:,2))).^2 (N*log(1+c(:,2))).^3 (N*log(1+c(:,2))).^4 N_2*log(1+c(:,2)) (N_2*log(1+c(:,2))).^2 (N_2*log(1+c(:,2))).^3 (N_2*log(1+c(:,2))).^4 hpop];
                    end
                end
            end
        end
    end
 
else if pop_treat==1
        XXXf = [zscore(X) NE*zscore(X) X_d pop]; 
        if instruments==0
            Z = [N*log(1+c) N*r (N*log(1+c)).^2 (N*r).^2 (N*log(1+c)).^3 (N*r).^3 (N*log(1+c)).^4 (N*r).^4 N_2*log(1+c) N_2*r (N_2*log(1+c)).^2 (N_2*r).^2 (N_2*log(1+c)).^3 (N_2*r).^3 (N_2*log(1+c)).^4 (N_2*r).^4 zscore(X) NE*zscore(X) X_d pop];
            
            ZZZf = [N*log(1+c) N*r (N*log(1+c)).^2 (N*r).^2 (N*log(1+c)).^3 (N*r).^3 (N*log(1+c)).^4 (N*r).^4 N_2*log(1+c) N_2*r (N_2*log(1+c)).^2 (N_2*r).^2 (N_2*log(1+c)).^3 (N_2*r).^3 (N_2*log(1+c)).^4 (N_2*r).^4];
        else if instruments==1
                Z = [N*log(1+c(:,2)) N*r (N*log(1+c(:,2))).^2 (N*r).^2 (N*log(1+c(:,2))).^3 (N*r).^3 (N*log(1+c(:,2))).^4 (N*r).^4 N_2*log(1+c(:,2)) N_2*r (N_2*log(1+c(:,2))).^2 (N_2*r).^2 (N_2*log(1+c(:,2))).^3 (N_2*r).^3 (N_2*log(1+c(:,2))).^4 (N_2*r).^4 zscore(X) NE*zscore(X) X_d pop];
                
                ZZZf = [N*log(1+c(:,2)) N*r (N*log(1+c(:,2))).^2 (N*r).^2 (N*log(1+c(:,2))).^3 (N*r).^3 (N*log(1+c(:,2))).^4 (N*r).^4 N_2*log(1+c(:,2)) N_2*r (N_2*log(1+c(:,2))).^2 (N_2*r).^2 (N_2*log(1+c(:,2))).^3 (N_2*r).^3 (N_2*log(1+c(:,2))).^4 (N_2*r).^4];
            else if instruments==2
                Z = [N*log(1+c) (N*log(1+c)).^2 (N*log(1+c)).^3 (N*log(1+c)).^4 N_2*log(1+c) (N_2*log(1+c)).^2 (N_2*log(1+c)).^3 (N_2*log(1+c)).^4 zscore(X) NE*zscore(X) X_d pop];
                
                ZZZf = [N*log(1+c) (N*log(1+c)).^2 (N*log(1+c)).^3 (N*log(1+c)).^4 N_2*log(1+c) (N_2*log(1+c)).^2 (N_2*log(1+c)).^3 (N_2*log(1+c)).^4];
                else if instruments==3
                    Z = [N*r (N*r).^2 (N*r).^3 (N*r).^4 N_2*r (N_2*r).^2 (N_2*r).^3 (N_2*r).^4 zscore(X) NE*zscore(X) X_d pop];
        
                    ZZZf = [N*r (N*r).^2 (N*r).^3 (N*r).^4 N_2*r (N_2*r).^2 (N_2*r).^3 (N_2*r).^4];
                    else if instruments==4
                        Z = [N*log(1+c(:,1)) (N*log(1+c(:,1))).^2 (N*log(1+c(:,1))).^3 (N*log(1+c(:,1))).^4 N_2*log(1+c(:,1)) (N_2*log(1+c(:,1))).^2 (N_2*log(1+c(:,1))).^3 (N_2*log(1+c(:,1))).^4 zscore(X) NE*zscore(X) X_d hpop];
        
                        ZZZf = [N*log(1+c(:,1)) (N*log(1+c(:,1))).^2 (N*log(1+c(:,1))).^3 (N*log(1+c(:,1))).^4 N_2*log(1+c(:,1)) (N_2*log(1+c(:,1))).^2 (N_2*log(1+c(:,1))).^3 (N_2*log(1+c(:,1))).^4];
                    else 
                        Z = [N*log(1+c(:,2)) (N*log(1+c(:,2))).^2 (N*log(1+c(:,2))).^3 (N*log(1+c(:,2))).^4 N_2*log(1+c(:,2)) (N_2*log(1+c(:,2))).^2 (N_2*log(1+c(:,2))).^3 (N_2*log(1+c(:,2))).^4 zscore(X) NE*zscore(X) X_d hpop];
        
                        ZZZf = [N*log(1+c(:,2)) (N*log(1+c(:,2))).^2 (N*log(1+c(:,2))).^3 (N*log(1+c(:,2))).^4 N_2*log(1+c(:,2)) (N_2*log(1+c(:,2))).^2 (N_2*log(1+c(:,2))).^3 (N_2*log(1+c(:,2))).^4];
                        end
                    end
                end
            end
        end
    end
end
 

XX = [s.^2 NE*s zscore(X) NE*zscore(X) X_d pop];       
YY =  zscore(p);

NN=N;
NN_2=N_2;

  if excl_viol==1
      Z = Z(~v,:);
      XX = XX(~v,:);
      YY = YY(~v,:);
      XXXf = XXXf(~v,:);
      ZZZf = ZZZf(~v,:);
      n = size(YY,1);
      NN=(N(~v,:))';
      NN=(NN(~v,:))';
      NN_2=(N_2(~v,:))';
      NN_2=(NN_2(~v,:))';
  end
    
%OLS
coeff_OLS_Prosp = (XX'*XX)\(XX'*YY);
disp('coefficients estimates for Prosperity Eq OLS')
disp([coeff_OLS_Prosp(1:2)]')

    % standard errors
    resid=YY-XX*coeff_OLS_Prosp;
    % construction of the variance of the coefficients estimators
    inside_part=0;
    for i=1:n
        inside_part=(resid(i))^2*XX(i,:)'*XX(i,:) + inside_part;               
    end
    var_coeff_OLS_Prosp=((XX'*XX)\(inside_part)/(XX'*XX));
    std_error_OLS_Prosp=sqrt(diag(var_coeff_OLS_Prosp));                                            % standard errors
    disp('standard errors for Prosperity Eq OLS')
    disp([std_error_OLS_Prosp(1:2)]')

    % spatial correlation-corrected standard errors
    OMEG= resid*resid';
    VU = sqrt(1/n)*((OMEG.*eye(n)) + ((2/3)*((OMEG.*NN)+(OMEG.*NN)')) + ((1/3)*((OMEG.*NN_2)+(OMEG.*NN_2)')));
    var_coeff_OLS_Prosp_Spatial = (XX'*XX)\XX'*VU*XX/(XX'*XX);
    std_error_OLS_Prosp_Spatial = sqrt(diag(var_coeff_OLS_Prosp_Spatial));
    disp('spatial standard errors for Prosperity Eq OLS')
    disp([std_error_OLS_Prosp_Spatial(1:2)]')
    
    
%IV
Q= XX'*Z*(inv(Z'*Z))*Z';
coeff_IV_Prosp=(Q*XX)\(Q*YY);             % estimation of the coefficients

coeff_s_sq = coeff_IV_Prosp(1);
ppsi2 = coeff_IV_Prosp(2);
disp('coefficients estimates for Prosperity Eq IV')
disp([coeff_IV_Prosp(1:2)]')


    % standard errors
    resid=YY-XX*coeff_IV_Prosp;
    % construction of the variance of the coefficients estimators
    inside_part=0;
    for i=1:n
        inside_part=(resid(i))^2*Z(i,:)'*Z(i,:) + inside_part;               
    end
    var_coeff_IV_Prosp=((XX'*Z*(inv(Z'*Z))*Z'*XX)\(XX'*Z*(inv(Z'*Z)))*inside_part*((inv(Z'*Z))*Z'*XX)/(XX'*Z*(inv(Z'*Z))*Z'*XX));
    std_error_IV_Prosp=sqrt(diag(var_coeff_IV_Prosp));                                            % standard errors
    disp('standard errors for Prosperity Eq IV')
    disp([std_error_IV_Prosp(1:2)]')

    %Spatial correlation-corrected standard errors
    OMEG= resid*resid';
    VU = sqrt(1/n)*((OMEG.*eye(n)) + ((2/3)*((OMEG.*NN)+(OMEG.*NN)')) + ((1/3)*((OMEG.*NN_2)+(OMEG.*NN_2)')));
    var_coeff_IV_Prosp_Spatial = (Q*XX)\Q*VU*Q'/(Q*XX);
    std_error_IV_Prosp_Spatial = sqrt(diag(var_coeff_IV_Prosp_Spatial)); 
    disp('spatial standard errors for Prosperity Eq IV')
    disp([std_error_IV_Prosp_Spatial(1:2)]')


    %Marginal Effects
    
    Avg_nij = NE(:);
    Avg_nij =  mean(Avg_nij(Avg_nij~=0));   
    
    if ass_network_structure<2
        disp('Average Marginal Effects for Prosperity Eq OLS')
        disp( ([2*mean(sqrt(XX(:,1))) Avg_nij].*coeff_OLS_Prosp(1:2)') )

        disp('Spatial standard errors for Marginal Effects Prosperity Eq OLS')
        disp( ([2*mean(sqrt(XX(:,1))) Avg_nij].*std_error_OLS_Prosp_Spatial(1:2)') )

        disp('Average Marginal Effects for Prosperity Eq IV')
        disp( ([2*mean(sqrt(XX(:,1))) Avg_nij].*coeff_IV_Prosp(1:2)') )

        disp('Spatial standard errors for Marginal Effects Prosperity Eq IV')
        disp( ([2*mean(sqrt(XX(:,1))) Avg_nij].*std_error_IV_Prosp_Spatial(1:2)') )
    else if ass_network_structure==2
            disp('Average Marginal Effects for Prosperity Eq OLS')
            disp( ([2*mean(sqrt(XX(:,1))) (n/5)*Avg_nij].*coeff_OLS_Prosp(1:2)') )

            disp('Spatial standard errors for Marginal Effects Prosperity Eq OLS')
            disp( ([2*mean(sqrt(XX(:,1))) (n/5)*Avg_nij].*std_error_OLS_Prosp_Spatial(1:2)') )

            disp('Average Marginal Effects for Prosperity Eq IV')
            disp( ([2*mean(sqrt(XX(:,1))) (n/5)*Avg_nij].*coeff_IV_Prosp(1:2)') )

            disp('Spatial standard errors for Marginal Effects Prosperity Eq IV')
            disp( ([2*mean(sqrt(XX(:,1))) (n/5)*Avg_nij].*std_error_IV_Prosp_Spatial(1:2)') )
        end
    end

       
    %First Stage 1
    coeff_1st_stage1_Prosp = (Z'*Z)\(Z'*XX(:,1));
    
    % standard errors
    resid=XX(:,1) - Z*coeff_1st_stage1_Prosp;
    % construction of the variance of the coefficients estimators
    inside_part=0;
    for i=1:n
        inside_part=(resid(i))^2*Z(i,:)'*Z(i,:) + inside_part;               
    end
    var_coeff_1st_stage1_Prosp=((Z'*Z)\(inside_part)/(Z'*Z));
    std_error_1st_stage1_Prosp=sqrt(diag(var_coeff_1st_stage1_Prosp));                                            % standard errors
    
    %Spatial correlation-corrected standard errors
    OMEG= resid*resid';
    VU = (OMEG.*eye(n)) + ((2/3)*((OMEG.*NN)+(OMEG.*NN)')) + ((1/3)*((OMEG.*NN_2)+(OMEG.*NN_2)'));
    var_coeff_1st_stage1_Prosp_Spatial =(Z'*Z)\Z'*VU*Z/(Z'*Z);
    std_error_1st_stage1_Prosp_Spatial=sqrt(diag(var_coeff_1st_stage1_Prosp_Spatial)); 
    
    
    R_sq1_Prosp = 1 - ((sum(resid.*resid)/sum((((XX(:,1)) - (sum(XX(:,1))/n)).^2))));
    disp('R squared First Stage 1')
    disp(R_sq1_Prosp)    

    R = [eye(size(Z,2)-k-ndep) zeros(size(Z,2)-k-ndep,k+ndep)];
    W = ((R*coeff_1st_stage1_Prosp)'/(R*var_coeff_1st_stage1_Prosp_Spatial*R'))*(R*coeff_1st_stage1_Prosp);
    p_val_1st_stage1 = 1 - chi2cdf(W,size(Z,2)-k-ndep);
    disp('p-value Wald test First Stage 1')
    disp(p_val_1st_stage1)
    
    
              if pop_treat==0
                %Modified F-statistic (multiple endogenous regressors: Angrist-Pischke (2009))
                XXXff = [Z*((Z'*Z)\(Z'*XX(:,2))) Z*((Z'*Z)\(Z'*XX(:,end))) XXXf];
                res_for_f = XX(:,1) - XXXff*((XXXff'*XXXff)\(XXXff'*XX(:,1)));

                coef_for_f =  (ZZZf'*ZZZf)\(ZZZf'*res_for_f);
    
                SSRr  = sum( (res_for_f - ones(n,1)*((ones(n,1)'*ones(n,1))\(ones(n,1)'*res_for_f)) ).^2);
                SSRur = sum( (res_for_f - ZZZf*coef_for_f).^2 );
    
                F_test = ((n-size(ZZZf,2))/size(ones(n,1),2))*(SSRr - SSRur)/SSRur;
                disp('F test for excluded instruments')
                disp('F-stat')
                disp(F_test)
                disp('p-value')
                disp(1-fcdf(F_test,size(ones(n,1),2),(n-size(ZZZf,2))))
    
                else if pop_treat==1
                %Modified F-statistic (multiple endogenous regressors: Angrist-Pischke (2009))
                XXXff = [Z*((Z'*Z)\(Z'*XX(:,2))) XXXf];
                res_for_f = XX(:,1) - XXXff*((XXXff'*XXXff)\(XXXff'*XX(:,1)));

                coef_for_f =  (ZZZf'*ZZZf)\(ZZZf'*res_for_f);
    
                SSRr  = sum( (res_for_f - ones(n,1)*((ones(n,1)'*ones(n,1))\(ones(n,1)'*res_for_f)) ).^2);
                SSRur = sum( (res_for_f - ZZZf*coef_for_f).^2 );
    
                F_test = ((n-size(ZZZf,2))/size(ones(n,1),2))*(SSRr - SSRur)/SSRur;
                disp('F test for excluded instruments')
                disp('F-stat')
                disp(F_test)
                disp('p-value')
                disp(1-fcdf(F_test,size(ones(n,1),2),(n-size(ZZZf,2))))
            
                    end
              end
    
  
    
    
    %First Stage 2
    coeff_1st_stage2_Prosp = (Z'*Z)\(Z'*XX(:,2));
    
    % standard errors
    resid=XX(:,2) - Z*coeff_1st_stage2_Prosp;
    % construction of the variance of the coefficients estimators
    inside_part=0;
    for i=1:n
        inside_part=(resid(i))^2*Z(i,:)'*Z(i,:) + inside_part;               
    end
    var_coeff_1st_stage2_Prosp=((Z'*Z)\(inside_part)/(Z'*Z));
    std_error_1st_stage2_Prosp=sqrt(diag(var_coeff_1st_stage2_Prosp));                                            % standard errors
    
    %Spatial correlation-corrected standard errors
    OMEG= resid*resid';
    VU = (OMEG.*eye(n)) + ((2/3)*((OMEG.*NN)+(OMEG.*NN)')) + ((1/3)*((OMEG.*NN_2)+(OMEG.*NN_2)'));
    var_coeff_1st_stage2_Prosp_Spatial =(Z'*Z)\Z'*VU*Z/(Z'*Z);
    std_error_1st_stage2_Prosp_Spatial=sqrt(diag(var_coeff_1st_stage2_Prosp_Spatial)); 
    
    
    R_sq2_Prosp = 1 - ((sum(resid.*resid)/sum(((XX(:,2) - (sum(XX(:,2))/n)).^2))));
    disp('R squared First Stage 2')
    disp(R_sq2_Prosp)    

    R = [eye(size(Z,2)-k-ndep) zeros(size(Z,2)-k-ndep,k+ndep)];
    W = ((R*coeff_1st_stage2_Prosp)'/(R*var_coeff_1st_stage2_Prosp_Spatial*R'))*(R*coeff_1st_stage2_Prosp);
    p_val_1st_stage2 = 1 - chi2cdf(W,size(Z,2)-k-ndep);
    disp('p-value Wald test First Stage 2')
    disp(p_val_1st_stage2)
     
    
              if pop_treat==0
                %Modified F-statistic (multiple endogenous regressors: Angrist-Pischke (2009))
                XXXff = [Z*((Z'*Z)\(Z'*XX(:,1))) Z*((Z'*Z)\(Z'*XX(:,end))) XXXf];
                res_for_f = XX(:,2) - XXXff*((XXXff'*XXXff)\(XXXff'*XX(:,2)));

                coef_for_f =  (ZZZf'*ZZZf)\(ZZZf'*res_for_f);
    
                SSRr  = sum( (res_for_f - ones(n,1)*((ones(n,1)'*ones(n,1))\(ones(n,1)'*res_for_f)) ).^2);
                SSRur = sum( (res_for_f - ZZZf*coef_for_f).^2 );
    
                F_test = ((n-size(ZZZf,2))/size(ones(n,1),2))*(SSRr - SSRur)/SSRur;
                disp('F test for excluded instruments')
                disp('F-stat')
                disp(F_test)
                disp('p-value')
                disp(1-fcdf(F_test,size(ones(n,1),2),(n-size(ZZZf,2))))
    
                else if pop_treat==1
                %Modified F-statistic (multiple endogenous regressors: Angrist-Pischke (2009))
                XXXff = [Z*((Z'*Z)\(Z'*XX(:,1))) XXXf];
                res_for_f = XX(:,2) - XXXff*((XXXff'*XXXff)\(XXXff'*XX(:,2)));

                coef_for_f =  (ZZZf'*ZZZf)\(ZZZf'*res_for_f);
    
                SSRr  = sum( (res_for_f - ones(n,1)*((ones(n,1)'*ones(n,1))\(ones(n,1)'*res_for_f)) ).^2);
                SSRur = sum( (res_for_f - ZZZf*coef_for_f).^2 );
    
                F_test = ((n-size(ZZZf,2))/size(ones(n,1),2))*(SSRr - SSRur)/SSRur;
                disp('F test for excluded instruments')
                disp('F-stat')
                disp(F_test)
                disp('p-value')
                disp(1-fcdf(F_test,size(ones(n,1),2),(n-size(ZZZf,2))))
            
                    end
              end
     
    
    
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            