%Estimation of State Capacity Spillovers: OUTCOMES EQUATION
%Acemoglu, Garcia-Jimeno, Robinson

clear all
close all
clc

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Import data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Open data file State_Capacity_Network_Work.mat
load State_Capacity_Network_Work.mat

%%
%OPTIONS

%1: Choose Outcome variable:
 out = 6;           %1 = Secondary enrollment 92-02
                    %2 = Services Coverage 1998
                    %3 = Not in poverty 2005
                    %4 = Life Quality Index
                    %5 = Literacy 1918
                    %6 = Schooling 1918
                    %7 = Vaccination 1918
                                                             
%2: Choose Measure of State Capacity:
 a_or_b = 0;        %0 = State municipality agencies 
                    %1 = State municipality bureaucracies
 
%3: Choose if control for national-level bureaucracy 
 nat_bur=0;         %0 = no 
                    %1 = yes

%4: Choose if control for rivers density and land shares
 river_land=0;      %0=no
                    %1=yes

%5: Choose if control for distance to current road
current_road=1;     %0=no
                    %1=yes
                    
%6: Choose assumption on Network Links
 ass_network_structure=0;       %0 = Network link is neighbors           
                                %1 = Network link is neighbors and neighbors of neighbors 

%7: Choose order of instruments: 
 order=2;           %2 = Instruments are Nc and N2c
                    %3 = Instruments are N2c and N3c 

%8: Choose the subset of Instruments to use:
 instruments=0;     %0 = All
                    %1 = Exclude Colonial Agencies
                    %2 = Exclude Royal Roads
                    %3 = Only Royal Roads
                    %4 = Only Crown Employees
                    %5 = Only Colonial Agencies

%9: Choose if exclude violent municipalities
excl_viol=0;        %0 = Do not exclude
                    %1 = Exclude from sample
                    %2 = Exclude from network

%10: Choose how to treat population
pop_treat=0;        %0=Instrument for Population with Historical Population
                    %1=Control for Population
%%

 %Choose the endogenous and exogenous variables for the model
    if out==1
         Yg_input = [(Yg(:,2)) YH];                                                    %Yg = Development Outcome
     else if out==2
         Yg_input = [(Yg(:,4)+Yg(:,5)+Yg(:,6))/3 YH];
         else if out==3
                 Yg_input = [Yg(:,9) YH];
             else if out==4
                 Yg_input = [Yg(:,10) YH];
                 else if out==5
                     Yg_input = YH(:,1);
                     else if out==6
                              Yg_input = YH(:,2);
                         else if out==7
                                  Yg_input = YH(:,3);
                             end
                         end
                     end
                 end
             end
         end
    end
                     
        

         
     %Choose if state capacity is agencies or bureaucracies    
     if a_or_b ==0
         S_input = S(:,6)+S(:,7)+S(:,8)+S(:,11)+S(:,12)+S(:,13)+S(:,14)+S(:,15)+S(:,16)+S(:,18)+S(:,19);                 %S = Contemporary State
     else
         S_input = S(:,1);
     end
         
     C_input = [C(:,1) C(:,3)];                                               %C = Colonial State
     R_input = R;                                                             %R = Distance to royal roads
     %
     %Choose controls
     if nat_bur==0 && river_land==0 && current_road==0                        %X = Controls
         X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5)];
        else if nat_bur==0 && river_land==0 && current_road==1
                X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) Xs(:,1)];               
            else if nat_bur==0 && river_land==1 && current_road==0
                    X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) G(:,6:8) L(:,1:7) L(:,12:15)];
                else if nat_bur==0 && river_land==1 && current_road==1
                        X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) Xs(:,1) G(:,6:8) L(:,1:7) L(:,12:15)];
                    else if nat_bur==1 && river_land==0 && current_road==0
                            X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) log(1+S(:,2))];
                        else if nat_bur==1 && river_land==0 && current_road==1
                                X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) Xs(:,1) log(1+S(:,2))];
                            else if nat_bur==1 && river_land==1 && current_road==0
                                    X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) G(:,6:8) L(:,1:7) L(:,12:15) log(1+S(:,2))];
                                else 
                                    X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) Xs(:,1) G(:,6:8) L(:,1:7) L(:,12:15) log(1+S(:,2))];
                                end
                            end
                        end
                    end
                end
            end
     end        
     
     X_input = [X_input H(:,8)./1000 H(:,9)];                                 %To add 1843 population and missing pop dummy
     
     %Ev_input = Ev;                                                          %Historical Electoral variability
     A_input = Adj;                                                           %A = Adjacency matrix
     Dd_input = Ddist;                                                        %Original Distances matrix
     Drr_input = Drankrange;                                                  %Original Range of elevation ranks along path matrix
     Drv_input = Drankvar;                                                    %Original Variance of elevation ranks along path matrix
     Yv_input = Yv(:,16);                                                     %Original Per capita attacks      
     
     
     %Clean data from missing values
     [Yg_clean S_clean C_clean X_clean R_clean Yv_clean A_clean Dd_clean Drr_clean Drv_clean DaneCodes_clean] = clean_missings(Yg_input, S_input, C_input, X_input, R_input, Yv_input, A_input, Dd_input, Drr_input, Drv_input, DaneCodes);

 clear Adj C DD Dc Ddist Drankrange Drankvar G H L R S Xs Yg Yv Ygini Ev DaneCodes
 clear Yg_input S_input C_input X_input R_input Yv_input Ev_input A_input Dd_input Drr_input Drv_input


 global p s c r
 p = Yg_clean(:,1);                     %p=vector of prosperity
 
 s= log(1+S_clean);                     %s=vector of state capacity  
 c = (C_clean);                         %c=vector of colonial state presence
 r = zscore(R_clean);                   %r=vector of distance to royal roads
 
 global D E
 D= Dd_clean;                           %D=distance matrix
 E= Drv_clean;                          %E=variance elevation matrix

 global X X_d pop hpop

 %Choose set of controls
   
    X = X_clean(:,28:end-2);                %matrix of controls
    
    hpop = X_clean(:,end-1:end);            %Matrix of 1843 population and missing 1843 population dummy
    X_d = X_clean(:,2:27);                  %matrix of department dummies and department capital dummy
    pop = X_clean(:,1)./1000;               %vector of population
 
 global A
 A=A_clean;                             %A=adjacency matrix (nxn) with 0s on the diagonal

 global n k ndep
 n=size(p,1);                           %number of observations
 k=size(X,2);                           %number of covariates
 ndep=size(X_d,2);                      %number of department dummies
 
 DaneCodes=DaneCodes_clean;             %Municipality codes to keep track
 
 %Create Indicator of violent municipalities (above 90th percentile of attacks)
 v=zeros(n,1);
 pc90 = prctile(Yv_clean,90);
 for j=1:n
     if Yv_clean(j,1)>=pc90
         v(j)=1;
     end
 end
 
 
 clear Yg_clean S_clean C_clean X_clean R_clean Yv_clean A_clean Dd_clean Drr_clean Drv_clean DaneCodes_clean
 
 
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Assumptions on the Network Structure
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if excl_viol==2
    p = p(~v,:);
    s = s(~v,:);
    c = c(~v,:);
    r = r(~v,:);
    X = X(~v,:);
    X_d =X_d(~v,:);
    pop = pop(~v,:);
    hpop = hpop(~v,:);
    
    D0 = D(~v,:)';
    D = (D0(~v,:))';
    
    E0 = E(~v,:)';
    E = (E0(~v,:))';
    
    A0 = A(~v,:)';
    A = (A0(~v,:))';

    clear D0 E0 A0

    n=size(p,1);
end

global NE N N_2 A_2 A_3
F=1./(1+(D.*(1+E)));

%Re-sets the diagonal to zeroes
for i=1:size(F,1)
    F(i,i)=0;
end

Q=(ones(n,n)-A).*(A*A-diag(diag(A*A)));                 %Matrix of Number of Paths to Neighbors of Neighbors who are not own Neighbors
A_2=ismember(Q,1:1:max(max(Q)));                        %Adjacency Matrix of neighbors of neighbors
A_2=+A_2;                                               % from logical to numeric

Q2=(ones(n,n)-A-A_2).*((A*A*A)-diag(diag(A*A*A)));      %Matrix of Number of Paths to Neighbors of Neighbors of Neighbors who are not own Neighbors or own Neighbors of Neighbors
A_3 = ismember(Q2,1:1:max(max(Q2)));                    %Adjacency Matrix of neighbors of neighbors of neighbors
A_3=+A_3;                                               % from logical to numeric
clear Q Q2


if ass_network_structure==1 
    A=(A+A_2);                                          %Adjacency matrix when Network link is defined by assumption b
    A_2=A_3;                                            %Adjacency matrix of neighbors of neighbors when Network link is defined by assumption b
end

%Network matrix of adjacent neighbors
NE = F.*A; 

if order==2
    N=F.*A;                                                 %Network matrix of neighbors
    N_2=F.*A_2;                                             %Network matrix of neighbors of neighbors
else if order==3
        N=F.*A_2;                                           %Network matrix of neighbors of neighbors
        N_2=F.*A_3;                                         %Network matrix of neighbors of neighbors of neighbors
    end
end

%%
%Reduced form of Historical Prosperity on Instruments

YY =  zscore(p);

%%
%Table 1
%Only Linear Instruments
XX = [N*log(1+c) N*r N_2*log(1+c) N_2*r zscore(X) X_d ones(n,1)];

disp('Only Linear Instruments and Covariates')

coeff = (XX'*XX)\(XX'*YY);

    % standard errors
    resid=YY-XX*coeff;
    % construction of the variance of the coefficients estimators
    inside_part=0;
    for i=1:n
        inside_part=(resid(i))^2*XX(i,:)'*XX(i,:) + inside_part;               
    end
    var_coeff=((XX'*XX)\(inside_part)/(XX'*XX));
    std_error=sqrt(diag(var_coeff));                                            % standard errors

    % spatial correlation-corrected standard errors
    OMEG= resid*resid';
    VU = (OMEG.*eye(n)) + ((2/3)*((OMEG.*N)+(OMEG.*N)')) + ((1/3)*((OMEG.*N_2)+(OMEG.*N_2)'));
    var_coeff_Spatial = (XX'*XX)\XX'*VU*XX/(XX'*XX);
    std_error_Spatial = sqrt(diag(var_coeff_Spatial));

    disp('coef std')
    disp([coeff std_error_Spatial])

    disp('t stat')
    disp(coeff./std_error_Spatial)
    
    
    %F-test of joint significance of instruments
    XXres =[zscore(X) X_d ones(n,1)];
    coef_res = (XXres'*XXres)\(XXres'*YY);
    resid_res = YY-XXres*coef_res;
    SSRres = sum(resid_res.*resid_res);
    SSRun = sum(resid.*resid);
    
    F_stat = ((SSRres-SSRun)/SSRun)*((n-size(XX,2))/(size(XX,2)-size(XXres,2)));
    disp('F test for all instruments')
    disp('F-stat')
    disp(F_stat)
    disp('p-value')
    disp(1-fcdf(F_stat,size(XX,2)-size(XXres,2),n-size(XX,2)))   
    

%Only Linear Instruments and 1843 pop   
XX = [N*log(1+c) N*r N_2*log(1+c) N_2*r zscore(X) X_d hpop(:,1) ones(n,1)];

disp('Only Linear Instruments and Covariates and 1843 pop')

coeff = (XX'*XX)\(XX'*YY);

    % standard errors
    resid=YY-XX*coeff;
    % construction of the variance of the coefficients estimators
    inside_part=0;
    for i=1:n
        inside_part=(resid(i))^2*XX(i,:)'*XX(i,:) + inside_part;               
    end
    var_coeff=((XX'*XX)\(inside_part)/(XX'*XX));
    std_error=sqrt(diag(var_coeff));                                            % standard errors

    % spatial correlation-corrected standard errors
    OMEG= resid*resid';
    VU = (OMEG.*eye(n)) + ((2/3)*((OMEG.*N)+(OMEG.*N)')) + ((1/3)*((OMEG.*N_2)+(OMEG.*N_2)'));
    var_coeff_Spatial = (XX'*XX)\XX'*VU*XX/(XX'*XX);
    std_error_Spatial = sqrt(diag(var_coeff_Spatial));

    disp('coef std')
    disp([coeff std_error_Spatial])

    disp('t stat')
    disp(coeff./std_error_Spatial)
    
    
    %F-test of joint significance of instruments
    XXres =[zscore(X) X_d hpop(:,1) ones(n,1)];
    coef_res = (XXres'*XXres)\(XXres'*YY);
    resid_res = YY-XXres*coef_res;
    SSRres = sum(resid_res.*resid_res);
    SSRun = sum(resid.*resid);
    
    F_stat = ((SSRres-SSRun)/SSRun)*((n-size(XX,2))/(size(XX,2)-size(XXres,2)));
    disp('F test for all instruments')
    disp('F-stat')
    disp(F_stat)
    disp('p-value')
    disp(1-fcdf(F_stat,size(XX,2)-size(XXres,2),n-size(XX,2)))   
    

%Instruments
XX = [N*log(1+c) N*r (N*log(1+c)).^2 (N*r).^2 (N*log(1+c)).^3 (N*r).^3 (N*log(1+c)).^4 (N*r).^4 N_2*log(1+c) N_2*r (N_2*log(1+c)).^2 (N_2*r).^2 (N_2*log(1+c)).^3 (N_2*r).^3 (N_2*log(1+c)).^4 (N_2*r).^4 zscore(X) X_d ones(n,1)];

disp('Instruments and Covariates')

coeff = (XX'*XX)\(XX'*YY);

    % standard errors
    resid=YY-XX*coeff;
    % construction of the variance of the coefficients estimators
    inside_part=0;
    for i=1:n
        inside_part=(resid(i))^2*XX(i,:)'*XX(i,:) + inside_part;               
    end
    var_coeff=((XX'*XX)\(inside_part)/(XX'*XX));
    std_error=sqrt(diag(var_coeff));                                            % standard errors
 

    % spatial correlation-corrected standard errors
    OMEG= resid*resid';
    VU = (OMEG.*eye(n)) + ((2/3)*((OMEG.*N)+(OMEG.*N)')) + ((1/3)*((OMEG.*N_2)+(OMEG.*N_2)'));
    var_coeff_Spatial = (XX'*XX)\XX'*VU*XX/(XX'*XX);
    std_error_Spatial = sqrt(diag(var_coeff_Spatial));

    disp('coef std')
    disp([coeff std_error_Spatial])

    disp('t stat')
    disp(coeff./std_error_Spatial)
    
    %F-test of joint significance of instruments
    XXres =[zscore(X) X_d ones(n,1)];
    coef_res = (XXres'*XXres)\(XXres'*YY);
    resid_res = YY-XXres*coef_res;
    SSRres = sum(resid_res.*resid_res);
    SSRun = sum(resid.*resid);
    
    F_stat = ((SSRres-SSRun)/SSRun)*((n-size(XX,2))/(size(XX,2)-size(XXres,2)));
    disp('F test for all instruments')
    disp('F-stat')
    disp(F_stat)
    disp('p-value')
    disp(1-fcdf(F_stat,size(XX,2)-size(XXres,2),n-size(XX,2)))
    
    
%Instruments, and 1843 pop
XX = [N*log(1+c) N*r (N*log(1+c)).^2 (N*r).^2 (N*log(1+c)).^3 (N*r).^3 (N*log(1+c)).^4 (N*r).^4 N_2*log(1+c) N_2*r (N_2*log(1+c)).^2 (N_2*r).^2 (N_2*log(1+c)).^3 (N_2*r).^3 (N_2*log(1+c)).^4 (N_2*r).^4 zscore(X) X_d hpop(:,1) ones(n,1)];

disp('Instruments, Covariates, and 1843 pop')

coeff = (XX'*XX)\(XX'*YY);

    % standard errors
    resid=YY-XX*coeff;
    % construction of the variance of the coefficients estimators
    inside_part=0;
    for i=1:n
        inside_part=(resid(i))^2*XX(i,:)'*XX(i,:) + inside_part;               
    end
    var_coeff=((XX'*XX)\(inside_part)/(XX'*XX));
    std_error=sqrt(diag(var_coeff));                                            % standard errors

    % spatial correlation-corrected standard errors
    OMEG= resid*resid';
    VU = (OMEG.*eye(n)) + ((2/3)*((OMEG.*N)+(OMEG.*N)')) + ((1/3)*((OMEG.*N_2)+(OMEG.*N_2)'));
    var_coeff_Spatial = (XX'*XX)\XX'*VU*XX/(XX'*XX);
    std_error_Spatial = sqrt(diag(var_coeff_Spatial));

    disp('coef std')
    disp([coeff std_error_Spatial])

    disp('t stat')
    disp(coeff./std_error_Spatial)
   
    %F-test of joint significance of instruments
    XXres =[zscore(X) X_d hpop(:,1) ones(n,1)];
    coef_res = (XXres'*XXres)\(XXres'*YY);
    resid_res = YY-XXres*coef_res;
    SSRres = sum(resid_res.*resid_res);
    SSRun = sum(resid.*resid);
    
    F_stat = ((SSRres-SSRun)/SSRun)*((n-size(XX,2))/(size(XX,2)-size(XXres,2)));
    disp('F test for all instruments')
    disp('F-stat')
    disp(F_stat)
    disp('p-value')
    disp(1-fcdf(F_stat,size(XX,2)-size(XXres,2),n-size(XX,2)))

     
    
%Own Colonial State and Linear Instruments
XX = [log(1+c) r N*log(1+c) N*r N_2*log(1+c) N_2*r zscore(X) X_d ones(n,1)];

disp('Only Linear Own Colonial State and Instruments')

coeff = (XX'*XX)\(XX'*YY);

    % standard errors
    resid=YY-XX*coeff;
    % construction of the variance of the coefficients estimators
    inside_part=0;
    for i=1:n
        inside_part=(resid(i))^2*XX(i,:)'*XX(i,:) + inside_part;               
    end
    var_coeff=((XX'*XX)\(inside_part)/(XX'*XX));
    std_error=sqrt(diag(var_coeff));                                            % standard errors

    % spatial correlation-corrected standard errors
    OMEG= resid*resid';
    VU = (OMEG.*eye(n)) + ((2/3)*((OMEG.*N)+(OMEG.*N)')) + ((1/3)*((OMEG.*N_2)+(OMEG.*N_2)'));
    var_coeff_Spatial = (XX'*XX)\XX'*VU*XX/(XX'*XX);
    std_error_Spatial = sqrt(diag(var_coeff_Spatial));

    disp('coef std')
    disp([coeff std_error_Spatial])

    disp('t stat')
    disp(coeff./std_error_Spatial)
    
    
    %F-test of joint significance of instruments
    XXres =[zscore(X) X_d ones(n,1)];
    coef_res = (XXres'*XXres)\(XXres'*YY);
    resid_res = YY-XXres*coef_res;
    SSRres = sum(resid_res.*resid_res);
    SSRun = sum(resid.*resid);
    
    F_stat = ((SSRres-SSRun)/SSRun)*((n-size(XX,2))/(size(XX,2)-size(XXres,2)));
    disp('F test for all instruments')
    disp('F-stat')
    disp(F_stat)
    disp('p-value')
    disp(1-fcdf(F_stat,size(XX,2)-size(XXres,2),n-size(XX,2)))        
    
    
%Own Colonial State and All Instruments
XX = [log(1+c) r N*log(1+c) N*r (N*log(1+c)).^2 (N*r).^2 (N*log(1+c)).^3 (N*r).^3 (N*log(1+c)).^4 (N*r).^4 N_2*log(1+c) N_2*r (N_2*log(1+c)).^2 (N_2*r).^2 (N_2*log(1+c)).^3 (N_2*r).^3 (N_2*log(1+c)).^4 (N_2*r).^4 zscore(X) X_d ones(n,1)];

disp('Own Colonial State and All Instruments')

coeff = (XX'*XX)\(XX'*YY);

    % standard errors
    resid=YY-XX*coeff;
    % construction of the variance of the coefficients estimators
    inside_part=0;
    for i=1:n
        inside_part=(resid(i))^2*XX(i,:)'*XX(i,:) + inside_part;               
    end
    var_coeff=((XX'*XX)\(inside_part)/(XX'*XX));
    std_error=sqrt(diag(var_coeff));                                            % standard errors

    % spatial correlation-corrected standard errors
    OMEG= resid*resid';
    VU = (OMEG.*eye(n)) + ((2/3)*((OMEG.*N)+(OMEG.*N)')) + ((1/3)*((OMEG.*N_2)+(OMEG.*N_2)'));
    var_coeff_Spatial = (XX'*XX)\XX'*VU*XX/(XX'*XX);
    std_error_Spatial = sqrt(diag(var_coeff_Spatial));

    disp('coef std')
    disp([coeff std_error_Spatial])

    disp('t stat')
    disp(coeff./std_error_Spatial)
    
    
    %F-test of joint significance of instruments
    XXres =[zscore(X) X_d ones(n,1)];
    coef_res = (XXres'*XXres)\(XXres'*YY);
    resid_res = YY-XXres*coef_res;
    SSRres = sum(resid_res.*resid_res);
    SSRun = sum(resid.*resid);
    
    F_stat = ((SSRres-SSRun)/SSRun)*((n-size(XX,2))/(size(XX,2)-size(XXres,2)));
    disp('F test for all instruments')
    disp('F-stat')
    disp(F_stat)
    disp('p-value')
    disp(1-fcdf(F_stat,size(XX,2)-size(XXres,2),n-size(XX,2)))         

    
%%
%Table 2
%Only Neighbors
XX = [N*log(1+c) N*r zscore(X) X_d ones(n,1)];

disp('Only Linear Instruments and Covariates')

coeff = (XX'*XX)\(XX'*YY);

    % standard errors
    resid=YY-XX*coeff;
    % construction of the variance of the coefficients estimators
    inside_part=0;
    for i=1:n
        inside_part=(resid(i))^2*XX(i,:)'*XX(i,:) + inside_part;               
    end
    var_coeff=((XX'*XX)\(inside_part)/(XX'*XX));
    std_error=sqrt(diag(var_coeff));                                            % standard errors

    % spatial correlation-corrected standard errors
    OMEG= resid*resid';
    VU = (OMEG.*eye(n)) + ((2/3)*((OMEG.*N)+(OMEG.*N)')) + ((1/3)*((OMEG.*N_2)+(OMEG.*N_2)'));
    var_coeff_Spatial = (XX'*XX)\XX'*VU*XX/(XX'*XX);
    std_error_Spatial = sqrt(diag(var_coeff_Spatial));

    disp('coef std')
    disp([coeff std_error_Spatial])

    disp('t stat')
    disp(coeff./std_error_Spatial)
    
    
    %F-test of joint significance of instruments
    XXres =[zscore(X) X_d ones(n,1)];
    coef_res = (XXres'*XXres)\(XXres'*YY);
    resid_res = YY-XXres*coef_res;
    SSRres = sum(resid_res.*resid_res);
    SSRun = sum(resid.*resid);
    
    F_stat = ((SSRres-SSRun)/SSRun)*((n-size(XX,2))/(size(XX,2)-size(XXres,2)));
    disp('F test for all instruments')
    disp('F-stat')
    disp(F_stat)
    disp('p-value')
    disp(1-fcdf(F_stat,size(XX,2)-size(XXres,2),n-size(XX,2)))  

    
%Only Neighbors and pop

if out<5
    XX = [N*log(1+c) N*r zscore(X) X_d log(pop) ones(n,1)];
else
    XX = [N*log(1+c) N*r zscore(X) X_d hpop(:,1) ones(n,1)];
end

disp('Only Linear Instruments and Covariates and 1843 Pop')

coeff = (XX'*XX)\(XX'*YY);

    % standard errors
    resid=YY-XX*coeff;
    % construction of the variance of the coefficients estimators
    inside_part=0;
    for i=1:n
        inside_part=(resid(i))^2*XX(i,:)'*XX(i,:) + inside_part;               
    end
    var_coeff=((XX'*XX)\(inside_part)/(XX'*XX));
    std_error=sqrt(diag(var_coeff));                                            % standard errors

    % spatial correlation-corrected standard errors
    OMEG= resid*resid';
    VU = (OMEG.*eye(n)) + ((2/3)*((OMEG.*N)+(OMEG.*N)')) + ((1/3)*((OMEG.*N_2)+(OMEG.*N_2)'));
    var_coeff_Spatial = (XX'*XX)\XX'*VU*XX/(XX'*XX);
    std_error_Spatial = sqrt(diag(var_coeff_Spatial));

    disp('coef std')
    disp([coeff std_error_Spatial])

    disp('t stat')
    disp(coeff./std_error_Spatial)
    
    
    %F-test of joint significance of instruments
    if out<5
        XXres =[zscore(X) X_d log(pop) ones(n,1)];
    else
        XXres =[zscore(X) X_d hpop(:,1) ones(n,1)];
    end
    coef_res = (XXres'*XXres)\(XXres'*YY);
    resid_res = YY-XXres*coef_res;
    SSRres = sum(resid_res.*resid_res);
    SSRun = sum(resid.*resid);
    
    F_stat = ((SSRres-SSRun)/SSRun)*((n-size(XX,2))/(size(XX,2)-size(XXres,2)));
    disp('F test for all instruments')
    disp('F-stat')
    disp(F_stat)
    disp('p-value')
    disp(1-fcdf(F_stat,size(XX,2)-size(XXres,2),n-size(XX,2)))   
    
    
%%
%Table 3
%Own Colonial State    
XX = [log(1+c) r zscore(X) X_d ones(n,1)];

disp('Only Linear Own Colonial State')

coeff = (XX'*XX)\(XX'*YY);

    % standard errors
    resid=YY-XX*coeff;
    % construction of the variance of the coefficients estimators
    inside_part=0;
    for i=1:n
        inside_part=(resid(i))^2*XX(i,:)'*XX(i,:) + inside_part;               
    end
    var_coeff=((XX'*XX)\(inside_part)/(XX'*XX));
    std_error=sqrt(diag(var_coeff));                                            % standard errors

    % spatial correlation-corrected standard errors
    OMEG= resid*resid';
    VU = (OMEG.*eye(n)) + ((2/3)*((OMEG.*N)+(OMEG.*N)')) + ((1/3)*((OMEG.*N_2)+(OMEG.*N_2)'));
    var_coeff_Spatial = (XX'*XX)\XX'*VU*XX/(XX'*XX);
    std_error_Spatial = sqrt(diag(var_coeff_Spatial));

    disp('coef std')
    disp([coeff std_error_Spatial])

    disp('t stat')
    disp(coeff./std_error_Spatial)
    
    
    %F-test of joint significance of instruments
    XXres =[zscore(X) X_d ones(n,1)];
    coef_res = (XXres'*XXres)\(XXres'*YY);
    resid_res = YY-XXres*coef_res;
    SSRres = sum(resid_res.*resid_res);
    SSRun = sum(resid.*resid);
    
    F_stat = ((SSRres-SSRun)/SSRun)*((n-size(XX,2))/(size(XX,2)-size(XXres,2)));
    disp('F test for all instruments')
    disp('F-stat')
    disp(F_stat)
    disp('p-value')
    disp(1-fcdf(F_stat,size(XX,2)-size(XXres,2),n-size(XX,2)))      

    
%Own Colonial State    
XX = [log(1+c) r zscore(X) X_d hpop(:,1) ones(n,1)];

disp('Only Linear Own Colonial State')

coeff = (XX'*XX)\(XX'*YY);

    % standard errors
    resid=YY-XX*coeff;
    % construction of the variance of the coefficients estimators
    inside_part=0;
    for i=1:n
        inside_part=(resid(i))^2*XX(i,:)'*XX(i,:) + inside_part;               
    end
    var_coeff=((XX'*XX)\(inside_part)/(XX'*XX));
    std_error=sqrt(diag(var_coeff));                                            % standard errors

    % spatial correlation-corrected standard errors
    OMEG= resid*resid';
    VU = (OMEG.*eye(n)) + ((2/3)*((OMEG.*N)+(OMEG.*N)')) + ((1/3)*((OMEG.*N_2)+(OMEG.*N_2)'));
    var_coeff_Spatial = (XX'*XX)\XX'*VU*XX/(XX'*XX);
    std_error_Spatial = sqrt(diag(var_coeff_Spatial));

    disp('coef std')
    disp([coeff std_error_Spatial])

    disp('t stat')
    disp(coeff./std_error_Spatial)
    
    
    %F-test of joint significance of instruments
    XXres =[zscore(X) X_d hpop(:,1) ones(n,1)];
    coef_res = (XXres'*XXres)\(XXres'*YY);
    resid_res = YY-XXres*coef_res;
    SSRres = sum(resid_res.*resid_res);
    SSRun = sum(resid.*resid);
    
    F_stat = ((SSRres-SSRun)/SSRun)*((n-size(XX,2))/(size(XX,2)-size(XXres,2)));
    disp('F test for all instruments')
    disp('F-stat')
    disp(F_stat)
    disp('p-value')
    disp(1-fcdf(F_stat,size(XX,2)-size(XXres,2),n-size(XX,2)))    