%Estimation of State Capacity Spillovers: SYSTEM GMM GENERAL MODEL
%Acemoglu, Garcia-Jimeno, Robinson

clear all
close all
clc

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Import data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Open data file State_Capacity_Network_Work.mat
load State_Capacity_Network_Work.mat

%%
%OPTIONS

%1: Choose Outcome variable:
 %out = 3;          %1 = Secondary enrollment 92-02
                    %2 = Services Coverage 1998
                    %3 = Not in poverty 2005
                    %4 = Life Quality Index
                    %5 = Primary enrollment 92-02 (placebo)
                    %6 = Vaccination coverage 1998 (placebo)    
                                       
%2: Choose Measure of State Capacity:
 a_or_b = 0;        %0 = State municipality agencies 
                    %1 = State municipality bureaucracies
 
%3: Choose if control for national-level bureaucracy 
 nat_bur=0;         %0 = no 
                    %1 = yes

%4: Choose if control for rivers density and land shares
 river_land=0;      %0=no
                    %1=yes

%5: Choose if control for distance to current road
current_road=1;     %0=no
                    %1=yes
                    
%6: Choose assumption on Network Links
 ass_network_structure=0;       %0 = Network link is neighbors           
                                %1 = Network link is neighbors and neighbors of neighbors 

%7: Choose order of instruments: 
 order=2;           %2 = Instruments are Nc and N2c
                    %3 = Instruments are N2c and N3c 

%8: Choose the subset of Instruments to use:
 instruments=0;     %0 = Royal roads and Colonial Agencies
                    %1 = Royal roads only
                    %2 = Colonial Agencies only

%9: Choose if exclude violent municipalities
excl_viol=0;        %0 = Do not exclude
                    %1 = Exclude from sample
                    %2 = Exclude from network

%10: Choose how to treat population
pop_treat=0;        %0=Instrument for Population with Historical Population
                    %1=Control for Population                    
%%

 %Choose the endogenous and exogenous variables for the model
 Yg_input = [Yg(:,2) ((Yg(:,4)+Yg(:,5)+Yg(:,6))/3) Yg(:,9) Yg(:,10)];    
         
     %Choose if state capacity is agencies or bureaucracies    
    if a_or_b ==0
         S_input = [S(:,6)+S(:,7)+S(:,8)+S(:,11)+S(:,12)+S(:,13)+S(:,14)+S(:,15)+S(:,16)+S(:,18)+S(:,19) S(:,2)];                 %S = Contemporary State
     else
         S_input = [S(:,1) S(:,2)];
     end
         
     C_input = [C(:,1) C(:,3)];                                               %C = Colonial State
     R_input = R;                                                             %R = Distance to royal roads
     
     %Choose controls
     if nat_bur==0 && river_land==0 && current_road==0                        %X = Controls
         X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5)];
        else if nat_bur==0 && river_land==0 && current_road==1
                X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) Xs(:,1)];               
            else if nat_bur==0 && river_land==1 && current_road==0
                    X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) G(:,6:8) L(:,1:7) L(:,12:15)];
                else if nat_bur==0 && river_land==1 && current_road==1
                        X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) Xs(:,1) G(:,6:8) L(:,1:7) L(:,12:15)];
                    else if nat_bur==1 && river_land==0 && current_road==0
                            X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) log(1+S(:,2))];
                        else if nat_bur==1 && river_land==0 && current_road==1
                                X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) Xs(:,1) log(1+S(:,2))];
                            else if nat_bur==1 && river_land==1 && current_road==0
                                    X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) G(:,6:8) L(:,1:7) L(:,12:15) log(1+S(:,2))];
                                else 
                                    X_input = [Xs(:,2) DD(:,1:25) Dc G(:,1:5) Xs(:,1) G(:,6:8) L(:,1:7) L(:,12:15) log(1+S(:,2))];
                                end
                            end
                        end
                    end
                end
            end
     end        

                                                        
     X_input = [X_input H(:,8)./1000 H(:,9)];                                 %To add 1843 population, missing 1843 pop dummy
     
     size_X_input = size(X_input,2);                                          %Number of covariates
 
     A_input = Adj;                                                           %A = Adjacency matrix
     Dd_input = Ddist;                                                        %Original Distances matrix
     Drr_input = Drankrange;                                                  %Original Range of elevation ranks along path matrix
     Drv_input = Drankvar;                                                    %Original Variance of elevation ranks along path matrix
     Yv_input = Yv(:,16);                                                     %Original Per capita attacks   
     
     
     %Clean data from missing values
     [Yg_clean S_clean C_clean X_clean R_clean Yv_clean A_clean Dd_clean Drr_clean Drv_clean DaneCodes_clean] = clean_missings(Yg_input, S_input, C_input, X_input, R_input, Yv_input, A_input, Dd_input, Drr_input, Drv_input, DaneCodes);

 clear Adj C DD Dc Ddist Drankrange Drankvar G H L R S Xs Yg Yv Ygini Ev DaneCodes NS
 clear Yg_input S_input C_input X_input R_input Yv_input Ev_input A_input Dd_input Drr_input Drv_input


 global p l b c r
 p = Yg_clean;                          %p=vectors of prosperity

 l= log(1+S_clean(:,1));                %l=vector of LOCAL state capacity  
 b= log(1+S_clean(:,2));                %b=vector of NATIONAL-LEVEL state capacity  
 
 c = (C_clean);                         %c=vector of colonial state presence
 r = zscore(R_clean);                   %r=vector of distance to royal roads
 
 global D E
 D= Dd_clean;                           %D=distance matrix
 E= Drv_clean;                          %E=variance elevation matrix

 global X X_d pop hpop

 %Choose set of controls
   
    X = X_clean(:,28:end-2);                                                %matrix of controls
   
    hpop = X_clean(:,end-1:end);                                            %matrix of 1843 population and missing 1843 population dummy
    X_d = X_clean(:,2:27);                                                  %matrix of department dummies and department capital dummy
    pop = X_clean(:,1)./1000;                                               %vector of population
 
 global A
 A=A_clean;                             %A=adjacency matrix (nxn) with 0s on the diagonal

 global n k ndep
 n=size(p,1);                           %number of observations
 k=size(X,2);                           %number of covariates
 ndep=size(X_d,2);                      %number of department dummies
 
 DaneCodes=DaneCodes_clean;             %Municipality codes to keep track
 
 %Create Indicator of violent municipalities (above 90th percentile of attacks)
 v=zeros(n,1);
 pc90 = prctile(Yv_clean,90);
 for j=1:n
     if Yv_clean(j,1)>=pc90
         v(j)=1;
     end
 end
 
 clear Yg_clean S_clean C_clean X_clean R_clean Yv_clean A_clean Dd_clean Drr_clean Drv_clean DaneCodes_clean YH
 
 
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Assumptions on the Network Structure
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if excl_viol==2
    p = p(~v,:);
    l = l(~v,:);
    c = c(~v,:);
    r = r(~v,:);
    X = X(~v,:);
    X_d =X_d(~v,:);
    pop = pop(~v,:);
    hpop = hpop(~v,:);
    
    D0 = D(~v,:)';
    D = (D0(~v,:))';
    
    E0 = E(~v,:)';
    E = (E0(~v,:))';
    
    A0 = A(~v,:)';
    A = (A0(~v,:))';

    clear D0 E0 A0

    n=size(p,1);
end

global NE N N_2 A_2 A_3
F=1./(1+(D.*(1+E)));

%Re-sets the diagonal to zeroes
for i=1:size(F,1)
    F(i,i)=0;
end

Q=(ones(n,n)-A).*(A*A-diag(diag(A*A)));                 %Matrix of Number of Paths to Neighbors of Neighbors who are not own Neighbors
A_2=ismember(Q,1:1:max(max(Q)));                        %Adjacency Matrix of neighbors of neighbors
A_2=+A_2;                                               % from logical to numeric

Q2=(ones(n,n)-A-A_2).*((A*A*A)-diag(diag(A*A*A)));      %Matrix of Number of Paths to Neighbors of Neighbors of Neighbors who are not own Neighbors or own Neighbors of Neighbors
A_3 = ismember(Q2,1:1:max(max(Q2)));                    %Adjacency Matrix of neighbors of neighbors of neighbors
A_3=+A_3;                                               % from logical to numeric
clear Q Q2


if ass_network_structure==1 
    A=(A+A_2);                                          %Adjacency matrix when Network link is defined by assumption b
    A_2=A_3;                                            %Adjacency matrix of neighbors of neighbors when Network link is defined by assumption b
end

%Network matrix of adjacent neighbors
NE = F.*A; 

if order==2
    N=F.*A;                                                 %Network matrix of neighbors
    N_2=F.*A_2;                                             %Network matrix of neighbors of neighbors
else if order==3
        N=F.*A_2;                                           %Network matrix of neighbors of neighbors
        N_2=F.*A_3;                                         %Network matrix of neighbors of neighbors of neighbors
    end
end
 
 %%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %SYSTEM GMM GENERAL MODEL
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% %Municipality-Level FOC
% %l = f( Ns , c1 , c2, r, , X , X_d)
%
% %Outcomes Equation
% %y = f(s, N*s, X , X_d)
  
%%%%%%First stage GMM
 
 assum_f_delta=0;    % if 0 we are using Assumption f(D,E), 1 if we are using assumption f(D,E,delta).
 options=optimset('Display','iter','MaxIter',60000,'MaxFunEvals',60000,'Algorithm','interior-point');
 biweight_kernel=0;                                      %0 for normal kernel, 1 for biweight kernel
 truncation_normal=160;                                  %Truncation for normal kernel: the lower the value, the stronger the truncation
 nobin=1;                                                %0 for using bins , 1 for using directly the grid of observations
 
 global num_out num_eq
 num_out= size(p,2);
 num_eq = num_out+1;  %One equation for each outcome plus the local-level best response
 
 
 global d_bar e_bar
     number_of_neighbors=sum(A,2);
     d_bar=(1/1)*(number_of_neighbors).^(-1).*sum(A.*D,2);
     e_bar=(1/1)*(number_of_neighbors).^(-1).*sum(A.*E,2);

     %Initialize parameter value for delta
      ddelta_guess = 1*ones(1,2);    
      
 if assum_f_delta==1     % if N(d) depends on delta (the neighbors matrices are assumed to depend on a parameter vector delta)
          
      ddelta=ddelta_guess;
      [ N_d, N_d_2, F_d] = neighbors_matrix( ddelta, order );  % call a function that generates the neighbors and neighbors of neighbors matrices which depend on delta
      NN=N_d;
      NN_2=N_d_2;    
     
      Z_out_w=[NN*log(1+c) NN*r (NN*log(1+c)).^2 (NN*r).^2 (NN*log(1+c)).^3 (NN*r).^3 (NN*log(1+c)).^4 (NN*r).^4 NN_2*log(1+c) NN_2*r (NN_2*log(1+c)).^2 (NN_2*r).^2 (NN_2*log(1+c)).^3 (NN_2*r).^3 (NN_2*log(1+c)).^4 (NN_2*r).^4 zscore(X) X_d hpop zscore(d_bar) zscore(e_bar)];
      Z_br_w =[NN*log(1+c) NN*r NN_2*log(1+c) NN_2*r log(1+c) r zscore(X) X_d log(hpop(:,1)) hpop(:,2) zscore(d_bar) zscore(e_bar)];
      
      
      lb = [  0   0 -Inf*ones(1,num_out + num_out*(k+1+ndep) + 3 + k + 1 + ndep)   0  0  0.5   0    0]';
      ub = [Inf Inf  Inf*ones(1,num_out + num_out*(k+1+ndep) + 3 + k + 1 + ndep) Inf  1  0.5 Inf  Inf]';    
 else
     NN=N;
     NN_2=N_2;
          
     Z_out_w=[NN*log(1+c) NN*r (NN*log(1+c)).^2 (NN*r).^2 (NN*log(1+c)).^3 (N*r).^3 (N*log(1+c)).^4 (N*r).^4 NN_2*log(1+c) NN_2*r (NN_2*log(1+c)).^2 (NN_2*r).^2 (NN_2*log(1+c)).^3 (NN_2*r).^3 (NN_2*log(1+c)).^4 (NN_2*r).^4 zscore(X) X_d hpop];
     Z_br_w =[NN*log(1+c) NN*r NN_2*log(1+c) NN_2*r log(1+c) r zscore(X) X_d log(hpop(:,1)) hpop(:,2)];           
       
     lb = [  0   0 -Inf*ones(1,num_out + num_out*(k+1+ndep) + 3 + k + 1 + ndep)   0  0  0.5]';
     ub = [Inf Inf  Inf*ones(1,num_out + num_out*(k+1+ndep) + 3 + k + 1 + ndep) Inf  1  0.5]';  
 end
 
 num_mom = (num_out*size(Z_out_w,2))+size(Z_br_w,2); %total number of moments
 
 %Instruments for the Weighting  Matrix
    Zw = zeros(num_eq,num_mom,n);
    for obs_n=1:n
        Zw(:,:,obs_n) = [kron(eye(num_out),Z_out_w(obs_n,:)) zeros(num_out,size(Z_br_w,2)); zeros(1,(num_out*size(Z_out_w,2))) Z_br_w(obs_n,:)];
    end  
  
    ZOZ=zeros(num_mom,num_mom);
 
    for i=1:n
        ZOZ = Zw(:,:,i)'*Zw(:,:,i) + ZOZ;
    end

      
    %Initialize parameter values
      
      theta_guess = 1;      
      psi_1_guess = 1;
      psi_2_guess = 0.01*ones(1,num_out);
      beta_out_guess = 0*ones(1,num_out*(k+1));
      zet_out_guess = 0*ones(1,num_out*ndep);
      phi_guess = 0.01*ones(1,3);
      beta_br_guess = 0.01*ones(1,k+1);
      zet_br_guess = 0.01*ones(1,ndep);
      sigma_guess = 1.22;
      a_guess = 0.2;
      tau_guess = 0.5;
      
      if assum_f_delta==1
          guess_gmm = [theta_guess psi_1_guess psi_2_guess beta_out_guess zet_out_guess phi_guess beta_br_guess zet_br_guess sigma_guess a_guess tau_guess ddelta_guess];   
          tic
            [param_gmm_first, fval_first] = fmincon(@(param_gmm) sys_gmm_objective_fun_general(param_gmm, assum_f_delta, truncation_normal, nobin, biweight_kernel, order, num_out, ZOZ), guess_gmm, [], [], [], [], lb, ub, [], options);
          toc
      
      else
          guess_gmm = [theta_guess psi_1_guess psi_2_guess beta_out_guess zet_out_guess phi_guess beta_br_guess zet_br_guess sigma_guess a_guess tau_guess];
          tic
            [param_gmm_first, fval_first] = fmincon(@(param_gmm) sys_gmm_objective_fun_general(param_gmm, assum_f_delta, truncation_normal, nobin, biweight_kernel, order, num_out, ZOZ), guess_gmm, [], [], [], [], lb, ub, [], options);
          toc
      end
  
 
 %%%%%%Second stage (efficient) System GMM
      
      theta = param_gmm_first(1);
      psi_1 = param_gmm_first(2);
      psi_2 = param_gmm_first(3:3+num_out-1);
      beta_out = param_gmm_first(3+num_out:3+num_out+(num_out*(k+1))-1)';
      zet_out = param_gmm_first(3+num_out+(num_out*(k+1)):3+num_out+(num_out*(k+1))+(num_out*ndep)-1)';
      phi = param_gmm_first(3+num_out+(num_out*(k+1))+(num_out*ndep):3+num_out+(num_out*(k+1))+(num_out*ndep)+3-1)';
      beta_br = param_gmm_first(3+num_out+(num_out*(k+1))+(num_out*ndep)+3:3+num_out+(num_out*(k+1))+(num_out*ndep)+3+k+1-1)';
      zet_br = param_gmm_first(3+num_out+(num_out*(k+1))+(num_out*ndep)+3+k+1:3+num_out+(num_out*(k+1))+(num_out*ndep)+3+k+1+ndep-1)';
      sigma = param_gmm_first(3+num_out+(num_out*(k+1))+(num_out*ndep)+3+k+1+ndep-1+1);
      alpha = param_gmm_first(3+num_out+(num_out*(k+1))+(num_out*ndep)+3+k+1+ndep-1+1+1);
      tau = param_gmm_first(3+num_out+(num_out*(k+1))+(num_out*ndep)+3+k+1+ndep-1+1+1+1);
      disp('alpha sigma')
      disp([alpha sigma])
      
if assum_f_delta==1                                            % if N(d) depends on delta (the neighbors matrices are assumed to depend on a parameter vector delta)      
      ddelta = param_gmm_first(end-1:end);   
      [ N_d, N_d_2, F_d] = neighbors_matrix( ddelta, order );  % call a function that generates the neighbors and neighbors of neighbors matrices which depend on delta
      NN=N_d;
      NN_2=N_d_2;
      
      Z_out_w=[NN*log(1+c) NN*r (NN*log(1+c)).^2 (NN*r).^2 (NN*log(1+c)).^3 (N*r).^3 (N*log(1+c)).^4 (N*r).^4 NN_2*log(1+c) NN_2*r (NN_2*log(1+c)).^2 (NN_2*r).^2 (NN_2*log(1+c)).^3 (NN_2*r).^3 (NN_2*log(1+c)).^4 (NN_2*r).^4 zscore(X) X_d hpop zscore(d_bar) zscore(e_bar)];
      Z_br_w =[NN*log(1+c) NN*r NN_2*log(1+c) NN_2*r log(1+c) r zscore(X) X_d log(hpop(:,1)) hpop(:,2) zscore(d_bar) zscore(e_bar)];
      
else
     NN=N;
     NN_2=N_2;
     
     Z_out_w=[NN*log(1+c) NN*r (NN*log(1+c)).^2 (NN*r).^2 (NN*log(1+c)).^3 (N*r).^3 (N*log(1+c)).^4 (N*r).^4 NN_2*log(1+c) NN_2*r (NN_2*log(1+c)).^2 (NN_2*r).^2 (NN_2*log(1+c)).^3 (NN_2*r).^3 (NN_2*log(1+c)).^4 (NN_2*r).^4 zscore(X) X_d hpop];
     Z_br_w =[NN*log(1+c) NN*r NN_2*log(1+c) NN_2*r log(1+c) r zscore(X) X_d log(hpop(:,1)) hpop(:,2)];
end      

%State Capacity Composite
if sigma==1
        s = (l.^alpha).*((tau*b).^(1-alpha));
    else
        s = ( (alpha.*(l.^((sigma-1)/sigma))) + ((1-alpha).*((tau*b).^((sigma-1)/sigma))) ).^(sigma/(sigma-1));
end
    
%Non parametric conditional expectation
    pphi=[phi; beta_br];
    xx=[log(1+c) r zscore(X) log(pop)];    
    exp_cond_g= nonparametric_conditional( (theta./alpha).*l.*((l./s).^(1/sigma)) - psi_1*(NN*s) - X_d*zet_br, xx, biweight_kernel, truncation_normal, pphi, nobin );  % It gives the conditional expectation of s+ppsi_gmm*N*s-X*bbeta_gmm conditional on c and lambda for each bin

    %Residuals Prosperity:
    Qt = zeros(n,num_out);
    for i=1:num_out
        Qt(:,i) = zscore(p(:,i)) - ((theta./alpha).*l.*s.*((l./s).^(1/sigma))) - (psi_2(i).*(NN*s)) - ([zscore(X) pop]*beta_out(((i-1)*k)+i:i*(k+1))) - (X_d*zet_out((1+((i*ndep)-ndep):i*ndep))); 
    end
    
    %Residuals Best Response Local 
    q_br = (theta./alpha).*l.*((l./s).^(1/sigma)) - psi_1*(NN*s) - exp_cond_g - X_d*zet_br;
        
        
    Qt = [Qt q_br];
        
    Q=Qt';
        
    %Residuals for the Weighting Matrix       
    OM=zeros(num_eq,num_eq,n);
    for obs_n=1:n
        OM(:,:,obs_n) =Q(:,obs_n)*Q(:,obs_n)';
    end
 
  
    %Instruments for the Weighting  Matrix
        Zw = zeros(num_eq,num_mom,n);
        for obs_n=1:n
            Zw(:,:,obs_n) = [kron(eye(num_out),Z_out_w(obs_n,:)) zeros(num_out,size(Z_br_w,2)); zeros(1,(num_out*size(Z_out_w,2))) Z_br_w(obs_n,:)];
        end  
        
    ZOZ=zeros(num_mom,num_mom);
    for i=1:n
        ZOZ = Zw(:,:,i)'*OM(:,:,i)*Zw(:,:,i) + ZOZ;
    end
   
 guess_gmm = param_gmm_first;
 options=optimset('Display','iter','MaxIter',200000,'MaxFunEvals',200000,'Algorithm','interior-point');
         tic
         [param_gmm_final, fval_final] = fmincon(@(param_gmm) sys_gmm_objective_fun_general(param_gmm, assum_f_delta, truncation_normal, nobin, biweight_kernel, order, num_out, ZOZ), guess_gmm, [], [], [], [], lb, ub, [], options);
         toc
 
         
      theta = param_gmm_final(1);
      psi_1 = param_gmm_final(2);
      psi_2 = param_gmm_final(3:3+num_out-1);
      beta_out = param_gmm_final(3+num_out:3+num_out+(num_out*(k+1))-1)';
      zet_out = param_gmm_final(3+num_out+(num_out*(k+1)):3+num_out+(num_out*(k+1))+(num_out*ndep)-1)';
      phi = param_gmm_final(3+num_out+(num_out*(k+1))+(num_out*ndep):3+num_out+(num_out*(k+1))+(num_out*ndep)+3-1)';
      beta_br = param_gmm_final(3+num_out+(num_out*(k+1))+(num_out*ndep)+3:3+num_out+(num_out*(k+1))+(num_out*ndep)+3+k+1-1)';
      zet_br = param_gmm_final(3+num_out+(num_out*(k+1))+(num_out*ndep)+3+k+1:3+num_out+(num_out*(k+1))+(num_out*ndep)+3+k+1+ndep-1)';
      sigma = param_gmm_final(3+num_out+(num_out*(k+1))+(num_out*ndep)+3+k+1+ndep-1+1);
      alpha = param_gmm_final(3+num_out+(num_out*(k+1))+(num_out*ndep)+3+k+1+ndep-1+1+1);
      tau = param_gmm_final(3+num_out+(num_out*(k+1))+(num_out*ndep)+3+k+1+ndep-1+1+1+1);                        
      
 if assum_f_delta==1                                            % if N(d) depends on delta (the neighbors matrices are assumed to depend on a parameter vector delta)      
      ddelta = param_gmm_final(end-1:end); 
      [ N_d, N_d_2, F_d] = neighbors_matrix( ddelta, order );  % call a function that generates the neighbors and neighbors of neighbors matrices which depend on delta
      NN=N_d;
      NN_2=N_d_2; 
 else
     NN=N;
     NN_2=N_2;
 end      

 %State Capacity Composite
if sigma==1
        s = (l.^alpha).*((tau*b).^(1-alpha));
    else
        s = ( (alpha.*(l.^((sigma-1)/sigma))) + ((1-alpha).*((tau*b).^((sigma-1)/sigma))) ).^(sigma/(sigma-1));
end
 
disp('parameters estimates for System GMM')
disp('theta')
disp(theta)
disp('psi1')
disp(psi_1)
disp('psi_2')
disp(psi_2)
disp('phi')
disp(phi')

disp('sigma')
disp(sigma)
disp('alpha')
disp(alpha)
disp('tau')
disp(tau)

if assum_f_delta==1
    disp('delta')
    disp(ddelta')
else
    delta=[1,1]';
end
    
    %Non parametric conditional expectation
    yy = (theta./alpha).*l.*((l./s).^(1/sigma)) - psi_1*(NN*s) - X_d*zet_br;
    xx = [log(1+c) r zscore(X) log(pop)];
    exp_cond_g = nonparametric_conditional( yy, xx, biweight_kernel, truncation_normal, [phi; beta_br], nobin );
    
kappa = theta.*exp_cond_g;
E_kappa = theta*mean(exp_cond_g);
disp('E[kappa]')
disp(E_kappa)

stdev_kappa = theta*std(exp_cond_g);
disp('Stdev Kappa')
disp(stdev_kappa)

%%
%%%% STANDARD ERRORS %%%%
 
    if assum_f_delta==1     %if 0 we are using Assumption f(D,E), 1 if we are using assumption f(D,E,delta).   
     DF(:,:,1)=-D.*(1+ddelta(2)*E).*(F_d).^(-2);
     DN(:,:,1)=A.*DF(:,:,1);
     DN_2(:,:,1)=A_2.*DF(:,:,1);
     DF(:,:,2)=-ddelta(1)*D.*E.*(F_d).^(-2);
     DN(:,:,2)=A.*DF(:,:,2);
     DN_2(:,:,2)=A_2.*DF(:,:,2);
     DZ_out_del(:,:,1)=[DN(:,:,1)*log(1+c) DN(:,:,1)*r (DN(:,:,1)*log(1+c)).^2 (DN(:,:,1)*r).^2 (DN(:,:,1)*log(1+c)).^3 (DN(:,:,1)*r).^3 (DN(:,:,1)*log(1+c)).^4 (DN(:,:,1)*r).^4 DN_2(:,:,1)*log(1+c) DN_2(:,:,1)*r (DN_2(:,:,1)*log(1+c)).^2 (DN_2(:,:,1)*r).^2 (DN_2(:,:,1)*log(1+c)).^3 (DN_2(:,:,1)*r).^3 (DN_2(:,:,1)*log(1+c)).^4 (DN_2(:,:,1)*r).^4];
     DZ_out_del(:,:,2)=[DN(:,:,2)*log(1+c) DN(:,:,2)*r (DN(:,:,2)*log(1+c)).^2 (DN(:,:,2)*r).^2 (DN(:,:,2)*log(1+c)).^3 (DN(:,:,2)*r).^3 (DN(:,:,2)*log(1+c)).^4 (DN(:,:,2)*r).^4 DN_2(:,:,2)*log(1+c) DN_2(:,:,2)*r (DN_2(:,:,2)*log(1+c)).^2 (DN_2(:,:,2)*r).^2 (DN_2(:,:,2)*log(1+c)).^3 (DN_2(:,:,2)*r).^3 (DN_2(:,:,2)*log(1+c)).^4 (DN_2(:,:,2)*r).^4];
     DZ_br_del(:,:,1)=[DN(:,:,1)*log(1+c) DN(:,:,1)*r DN_2(:,:,1)*log(1+c) DN_2(:,:,1)*r];
     DZ_br_del(:,:,2)=[DN(:,:,2)*log(1+c) DN(:,:,2)*r DN_2(:,:,2)*log(1+c) DN_2(:,:,2)*r];
     
      Z_out=[NN*log(1+c) NN*r (NN*log(1+c)).^2 (NN*r).^2 (NN*log(1+c)).^3 (N*r).^3 (N*log(1+c)).^4 (N*r).^4 NN_2*log(1+c) NN_2*r (NN_2*log(1+c)).^2 (NN_2*r).^2 (NN_2*log(1+c)).^3 (NN_2*r).^3 (NN_2*log(1+c)).^4 (NN_2*r).^4 zscore(X) X_d hpop zscore(d_bar) zscore(e_bar)];
      Z_br=[NN*log(1+c) NN*r NN_2*log(1+c) NN_2*r log(1+c) r zscore(X) X_d log(hpop(:,1)) hpop(:,2) zscore(d_bar) zscore(e_bar)];
    else
        Z_out=[NN*log(1+c) NN*r (NN*log(1+c)).^2 (NN*r).^2 (NN*log(1+c)).^3 (N*r).^3 (N*log(1+c)).^4 (N*r).^4 NN_2*log(1+c) NN_2*r (NN_2*log(1+c)).^2 (NN_2*r).^2 (NN_2*log(1+c)).^3 (NN_2*r).^3 (NN_2*log(1+c)).^4 (NN_2*r).^4 zscore(X) X_d hpop];
        Z_br=[NN*log(1+c) NN*r NN_2*log(1+c) NN_2*r log(1+c) r zscore(X) X_d log(hpop(:,1)) hpop(:,2)];
        
    end
 
    num_par=size(param_gmm_final,2);
    mom_br =size(Z_br,2);
    mom_out=size(Z_out,2);
    
%Construction of Z_Dq_Arr

    Zi_Arr = zeros(num_eq,num_mom,n);
        for obs_n=1:n
            Zi_Arr(:,:,obs_n) = [kron(eye(num_out),Z_out_w(obs_n,:)) zeros(num_out,size(Z_br_w,2)); zeros(1,(num_out*size(Z_out_w,2))) Z_br_w(obs_n,:)];
        end    
    
   %Non parametric conditional expectation
    pphi=[phi; beta_br];
    xx=[log(1+c) r zscore(X) log(pop)];    
    exp_cond_g= nonparametric_conditional( (theta./alpha).*l.*((l./s).^(1/sigma)) - psi_1*(NN*s) - X_d*zet_br, xx, biweight_kernel, truncation_normal, pphi, nobin );  % It gives the conditional expectation of s+ppsi_gmm*N*s-X*bbeta_gmm conditional on c and lambda for each bin

    %Residuals Prosperity:
    Qt = zeros(n,num_out);
    for i=1:num_out
        Qt(:,i) = zscore(p(:,i)) - ((theta./alpha).*l.*s.*((l./s).^(1/sigma))) - (psi_2(i).*(NN*s)) - ([zscore(X) pop]*beta_out(((i-1)*k)+i:i*(k+1))) - (X_d*zet_out((1+((i*ndep)-ndep):i*ndep))); 
    end
    
    %Residuals Best Response Local
        q_br = (theta./alpha).*l.*((l./s).^(1/sigma)) - psi_1*(NN*s) - exp_cond_g - X_d*zet_br;
        
        Qt = [Qt q_br];
        
        Q=Qt';
     
 
   %Construction of spatially correlated weighting matrix    
    OM0=zeros(num_eq,num_eq,n);
    for obs_n=1:n
        OM0(:,:,obs_n) =Q(:,obs_n)*Q(:,obs_n)';
    end    
    
    OM1=zeros(num_eq,num_eq,n);
    for i=1:n
        neigh_i=0;
        VUi=zeros(num_eq,num_eq,n);
        for j=1:n
            if A(i,j)==1
                neigh_i=neigh_i+1;
                VUi(:,:,j)=Q(:,i)*Q(:,j)';
            end
        end
        OM1(:,:,i)=(1/neigh_i)*sum(VUi,3);
    end
    
    OM2=zeros(num_eq,num_eq,n);
    for i=1:n
        neigh2_i=0;
        VU2i=zeros(num_eq,num_eq,n);
        for j=1:n
            if A_2(i,j)==1
                neigh2_i=neigh2_i+1;
                VU2i(:,:,j)=Q(:,i)*Q(:,j)';
            end
        end
        OM2(:,:,i)=(1/neigh2_i)*sum(VU2i,3);
    end
  
    %Instruments for the Weighting  Matrix
        Zw = zeros(num_eq,num_mom,n);
        for obs_n=1:n
            Zw(:,:,obs_n) = [kron(eye(num_out),Z_out_w(obs_n,:)) zeros(num_out,size(Z_br_w,2)); zeros(1,(num_out*size(Z_out_w,2))) Z_br_w(obs_n,:)];
        end  
        
    ZWZ=zeros(num_mom,num_mom);
    for i=1:n
        ZWZ = Zw(:,:,i)'*(OM0(:,:,i) +((2/23)*(OM1(:,:,i) + OM1(:,:,i)')) + ((1/23)*(OM2(:,:,i) + OM2(:,:,i)')) )*Zw(:,:,i) + ZWZ;
    end    
        
    
 %Average derivative of g(phi*c + X*b):
 g=[xx*pphi exp_cond_g];
 
 b_g = ([ones(n,1) g(:,1)]'*[ones(n,1) g(:,1)])\([ones(n,1) g(:,1)]'*g(:,2));
 g_prime=b_g(2);
 

 %Construction of Dq   (Gradient of equations)
 
 % derivatives of state capacity over parameters
 deriv_s_over_sigma=((alpha.*l.^((sigma-1)/sigma)-(alpha-1).*(b*tau).^((sigma-1)/sigma)).^(sigma/(sigma-1)).*(-sigma.*(-alpha.*l.*(b*tau).^(1/sigma)...
     +alpha.*(b*tau).*l.^(1/sigma)-(b*tau).*l.^(1/sigma)).*log(alpha.*l.^((sigma-1)/sigma)-(alpha-1).*(b*tau).^((sigma-1)/sigma))-alpha.*l.*(sigma-1).*(b*tau).^(1/sigma).*log(l)...
     +(alpha-1).*(b*tau).*(sigma-1).*log((b*tau)).*l.^(1/sigma)))./((sigma-1)^2 .*sigma.*(-alpha.*l.*(b*tau).^(1/sigma)+alpha.*(b*tau).*l.^(1/sigma)-(b*tau).*l.^(1/sigma)));
 
 deriv_s_over_tau=(1-alpha).*s.^(1/sigma).*b.^((sigma-1)/sigma).*tau.^(-1/sigma);
 
 deriv_s_over_alpha=(sigma/(sigma-1))*s.^(1/sigma).*(l.^((sigma-1)/sigma)-(tau*b).^((sigma-1)/sigma));
 
 Dq=zeros(num_eq,num_par,n);
 
 % Outcomes equations
 for j=1:num_out
     Dq(j,1,:)=(l.*s/alpha).*(((l./s).^(1/sigma)));
     Dq(j,2,:)=zeros(n,1);
     
     if j==1
         Dq(j,3,:)=-NN*s;
         Dq(j,4,:)=zeros(n,1);
         Dq(j,5,:)=zeros(n,1);
         Dq(j,6,:)=zeros(n,1);
     else if j==2
             Dq(j,3,:)=zeros(n,1);
             Dq(j,4,:)=-NN*s;
             Dq(j,5,:)=zeros(n,1);
             Dq(j,6,:)=zeros(n,1);
         else if j==3
                 Dq(j,3,:)=zeros(n,1);
                 Dq(j,4,:)=zeros(n,1);
                 Dq(j,5,:)=-NN*s;
                 Dq(j,6,:)=zeros(n,1);
             else if j==4
                     Dq(j,3,:)=zeros(n,1);
                     Dq(j,4,:)=zeros(n,1);
                     Dq(j,5,:)=zeros(n,1);
                     Dq(j,6,:)=-NN*s;
                 end
             end
         end
     end
     
     Dq(j,7+((j-1)*(k+1)):7+(j*(k+1))-1,:)=-[zscore(X) pop]';
     Dq(j,7+(num_out*(k+1))+((j-1)*ndep):7+(num_out*(k+1))+(j*ndep)-1,:)=-X_d';
     Dq(j,7+(num_out*(k+1))+(num_out*ndep):7+(num_out*(k+1))+(num_out*ndep)+3-1,:)=zeros(n,3)';
     Dq(j,7+(num_out*(k+1))+(num_out*ndep)+3:7+(num_out*(k+1))+(num_out*ndep)+3+k+1-1,:)=zeros(n,k+1)';
     Dq(j,7+(num_out*(k+1))+(num_out*ndep)+3+k+1:7+(num_out*(k+1))+(num_out*ndep)+3+k+1+ndep-1,:)=zeros(n,ndep)';
     
     Dq(j,7+(num_out*(k+1))+(num_out*ndep)+3+k+1+ndep,:)=-(theta./alpha).*(l.^((sigma+1)/sigma)).*s.^((sigma-1)/sigma).*(sigma^(-2)*log(s)+((sigma-1)/sigma)*s.^(-1).*deriv_s_over_sigma)-psi_2(j)*NN*deriv_s_over_sigma;
     
     Dq(j,7+(num_out*(k+1))+(num_out*ndep)+3+k+1+ndep+1,:)=(theta/(alpha^2))*((l.^(1+(1/sigma))).*((tau*b).^((sigma-1)/sigma)));     
     Dq(j,7+(num_out*(k+1))+(num_out*ndep)+3+k+1+ndep+2,:)=-(theta./alpha).*l.^((1+sigma)/sigma).*(-(1/sigma)*s.^(-(1+sigma)/sigma)).*deriv_s_over_tau;
     
     if assum_f_delta==1
         Dq(j,end-1,:)=-psi_2(j)*(DN(:,:,1)*s);
         Dq(j,end,:)=-psi_2(j)*(DN(:,:,2)*s);
     end
 end
 
 % Best response equation
 
 Dq(num_out+1,1,:)=(l./alpha).*(((l./s).^(1/sigma)));
 Dq(num_out+1,2,:)=-(1/psi_1)*(NN*s);
 Dq(num_out+1,3,:)=zeros(n,1);
 Dq(num_out+1,4,:)=zeros(n,1);
 Dq(num_out+1,5,:)=zeros(n,1);
 Dq(num_out+1,6,:)=zeros(n,1);
 Dq(num_out+1,7:7+(num_out*(k+1))-1,:)=zeros(n,num_out*(k+1))';
 Dq(num_out+1,7+(num_out*(k+1)):7+(num_out*(k+1))+(num_out*ndep)-1,:)=zeros(n,num_out*ndep)';
 Dq(num_out+1,7+(num_out*(k+1))+(num_out*ndep):7+(num_out*(k+1))+(num_out*ndep)+3-1,:)=-xx(:,1:3)'*g_prime;
 Dq(num_out+1,7+(num_out*(k+1))+(num_out*ndep)+3:7+(num_out*(k+1))+(num_out*ndep)+3+k+1-1,:)=-[zscore(X) log(pop)]'*g_prime;
 Dq(num_out+1,7+(num_out*(k+1))+(num_out*ndep)+3+k+1:7+(num_out*(k+1))+(num_out*ndep)+3+k+1+ndep-1,:)=-X_d';
 
 Dq(num_out+1,7+(num_out*(k+1))+(num_out*ndep)+3+k+1+ndep,:)=(theta./alpha).*(l.^((sigma+1)/sigma)).*s.^(-1/sigma).*(sigma^(-2)*log(s)-(sigma*s).^(-1).*deriv_s_over_sigma)-psi_1*NN*deriv_s_over_sigma;
 Dq(num_out+1,7+(num_out*(k+1))+(num_out*ndep)+3+k+1+ndep+1,:)=(theta/alpha)*l.*((l./s).^(1/sigma)).*( ((1/(1-sigma)).*(s.^(1+(1/sigma))).*( l.^((sigma-1)/sigma) - ((tau*b).^((sigma-1)/sigma)) ))   - (1/(alpha^2)) );  
 Dq(num_out+1,7+(num_out*(k+1))+(num_out*ndep)+3+k+1+ndep+2,:)=(theta./alpha).*(l.^((sigma+1)/sigma)).*(-(1/sigma)*s.^(-(1+sigma)/sigma)).*deriv_s_over_tau;

 if assum_f_delta==1
     Dq(num_out+1,end-1,:)=-psi_1*((DN(:,:,1)*s));
     Dq(num_out+1,end,:)=-psi_1*((DN(:,:,2)*s));
 end
 
 
 Z_Dq_Arr=zeros(num_mom,num_par,n);
 for i=1:n
     Z_Dq_Arr(:,:,i) = Zi_Arr(:,:,i)'*Dq(:,:,i);
 end
    
   
%Construction of DZ_q_Arr

    %Construction of DZ (Gradient of Instruments)
    DZout=zeros(mom_out,num_par,n);
    if assum_f_delta==1
        for i=1:size(DZ_out_del,2)
            DZout(i,end-1,:)= DZ_out_del(:,i,1);
        end
        for i=1:size(DZ_out_del,2)
            DZout(i,end,:)= DZ_out_del(:,i,2);
        end
    end
        
    DZbr=zeros(mom_br,num_par,n);
    if assum_f_delta==1    
        for i=1:size(DZ_br_del,2) 
            DZbr(i,end-1,:)= DZ_br_del(:,i,1);
        end 
        for i=1:size(DZ_br_del,2)
            DZbr(i,end,:)= DZ_br_del(:,i,2);
        end
    end
 
    DZ_q_Arr=zeros(num_mom,num_par,n);
    if assum_f_delta==1
    for i=1:n
        DZ_q_Arr(:,:,i)=[repmat(DZout(:,:,i),num_out,1); DZbr(:,:,i)].*(repmat([reshape(repmat(Q(1:num_out,i)',mom_out,1),mom_out*num_out,1) ; Q(end,i)*ones(mom_br,1)],1,num_par));
    end
    end
    
 %Construction of DG
 DG_Arr = Z_Dq_Arr + DZ_q_Arr;   
    
 DG = sum(DG_Arr,3);
 
 %% Variance Covariance Matrix of the GMM estimator
 
 
 Avar_gmm = inv((DG'/ZWZ)*DG);   
 
 std_errors_gmm = sqrt(diag(Avar_gmm));
 disp('Standar Errors for Parameter Estimates System GMM')
 disp('standard error theta')
 disp(std_errors_gmm(1)')
 disp('standard error psi_1')
 disp(std_errors_gmm(2)')
 disp('standard errors psi_2')
 disp(std_errors_gmm(3:6)')
 disp('standard errors beta outcomes')
 disp(std_errors_gmm(7:7+(num_out*(k+1))-1)')
 disp('standard errors zeta outcomese')
 disp(std_errors_gmm(7+(num_out*(k+1)):7+(num_out*(k+1))+(num_out*ndep)-1)')
 disp('standard error phi')
 disp(std_errors_gmm(7+(num_out*(k+1))+(num_out*ndep):7+(num_out*(k+1))+(num_out*ndep)+3-1)')
 disp('standard errors beta best response')
 disp(std_errors_gmm(7+(num_out*(k+1))+(num_out*ndep)+3:7+(num_out*(k+1))+(num_out*ndep)+3+k+1-1)')
 disp('standard errors zeta best response')
 disp(std_errors_gmm(7+(num_out*(k+1))+(num_out*ndep)+3+k+1:7+(num_out*(k+1))+(num_out*ndep)+3+k+1+ndep-1)')
 disp('standard errors sigma')
 disp(std_errors_gmm(3+num_out+(num_out*(k+1))+(num_out*ndep)+3+k+1+ndep-1+1))
 disp('standard errors alpha')
 disp(std_errors_gmm(3+num_out+(num_out*(k+1))+(num_out*ndep)+3+k+1+ndep-1+1+1))
 %disp('standard errors tau')
 %disp(std_errors_gmm(3+num_out+(num_out*(k+1))+(num_out*ndep)+3+k+1+ndep-1+1+1+1))
 
 if assum_f_delta==1
  disp('standard errors delta')
  disp(std_errors_gmm(end-1:end)')
 end


%%    
%Condition for Equilibrium Uniqueness
lambda_min = min(eig(NN));
disp('Lowest Eigenvalue of the Network Matrix')
disp(lambda_min)

TT = ((sigma+1)*((l./s).^(1/sigma))) - (alpha*(l./s)) ;

dl_dNs = TT./(psi_1*alpha*sigma./theta);

dl_dNs_inv=(dl_dNs).^(-1);

disp('Min (dl_dN(d)s)^(-1)')
disp(min(dl_dNs_inv))

disp('Max (dl_dN(d)s)^(-1)')
disp(max(dl_dNs_inv))

if ( min(dl_dNs_inv)>(1+(1/lambda_min)) ) && ( max(dl_dNs_inv)<1 )
     disp('Unique Equilibrium Condition Satisfied')
 else
     disp('Unique Equilibrium Condition Not Satisfied')
 end
     
%%
%Experiments
%Experiments consist of finding the zero of the system of non-linear best responses after different kinds of shocks. Use Newton-Raphson to find the roots

%Baseline:
l_0 = l.*ones(n,1);

%Shock to national state capacity
b_shock = zeros(n,1);

%Shock to weight of local state
alpha_sh = alpha;

%Shock to elasticity of substitution
sigma_sh = sigma ;

%Shock to marginal cost of local state
theta_sh = theta;

%Shock to interaction effect
psi_1_sh = psi_1;

%Shock to elasticity of national state tau
tau_sh = tau;

%Shock to "infrastructure"
delta_sh = 1*delta;
NN_sh = neighbors_matrix(delta_sh, order);

    Avg_nij_pr = NN_sh(:);
    Avg_nij_pr =  mean(Avg_nij_pr(Avg_nij_pr~=0))

    Avg_nij_pr*mean(l)*psi_1 + Avg_nij_pr*psi_2(1)  



BR(alpha_sh, sigma_sh, theta_sh, psi_1_sh, tau_sh, exp_cond_g, zet_br, NN_sh, b_shock, log(l_0))

f = @(x) BR(alpha_sh, sigma_sh, theta_sh, psi_1_sh, tau_sh, exp_cond_g, zet_br, NN_sh, b_shock, x) ; % function of dummy variable x

options = optimset('Display','iter', 'MaxFunEvals', 1000000, 'MaxIter', 1000);
[root, fval] = fsolve(f, log(l_0), options);

BR(alpha_sh, sigma_sh, theta_sh, psi_1_sh, tau_sh, exp_cond_g, zet_br, NN_sh, b_shock, root)

l_base = exp(root);

%Prosperity Outcomes
%Baseline
if sigma_sh==1
    s_base = (l_base.^alpha_sh).*((tau_sh*(b)).^(1-alpha_sh));
else
    s_base = ( (alpha_sh.*(l_base.^((sigma_sh-1)/sigma_sh))) + ((1-alpha_sh).*((tau_sh*(b)).^((sigma_sh-1)/sigma_sh))) ).^(sigma_sh/(sigma_sh-1));
end

p_base=zeros(n,num_out);
p_base_level=zeros(n,num_out);
for zz=1:num_out
    p_base(:,zz) = ( (theta_sh./alpha_sh).*l_base.*s_base.*((l_base./s_base).^(1/sigma_sh)) ) + (psi_2(zz).*(NN_sh*s_base)) + ([zscore(X) pop]*beta_out(((zz-1)*k)+zz:zz*(k+1))) + (X_d*zet_out((1+((zz*ndep)-ndep):zz*ndep)));
    p_base_level(:,zz) =((std(p(:,zz))*p_base(:,zz)) + mean(p(:,zz)));
end






%Experiment: Take below-median national-level state capacity to median
l_0 = l.*ones(n,1);
%l_0 = l_predict;

%Shock to national state capacity
b_shock = max(b, median(b))-b;

%Shock to weight of local state
alpha_sh = alpha;

%Shock to elasticity of substitution
sigma_sh = sigma ;

%Shock to marginal cost of local state
theta_sh = theta;

%Shock to interaction effect
psi_1_sh = psi_1;

%Shock to elasticity of national state tau
tau_sh = tau;

%Shock to "infrastructure"
delta_sh = 1*delta;
NN_sh = neighbors_matrix(delta_sh, order);

    Avg_nij_pr = NN_sh(:);
    Avg_nij_pr =  mean(Avg_nij_pr(Avg_nij_pr~=0))

    Avg_nij_pr*mean(l)*psi_1 + Avg_nij_pr*psi_2(1)  



BR(alpha_sh, sigma_sh, theta_sh, psi_1_sh, tau_sh, exp_cond_g, zet_br, NN_sh, b_shock, log(l_0))

f = @(x) BR(alpha_sh, sigma_sh, theta_sh, psi_1_sh, tau_sh, exp_cond_g, zet_br, NN_sh, b_shock, x) ; % function of dummy variable x

options = optimset('Display','iter', 'MaxFunEvals', 1000000, 'MaxIter', 1000);
[root, fval] = fsolve(f, log(l_0), options);

BR(alpha_sh, sigma_sh, theta_sh, psi_1_sh, tau_sh, exp_cond_g, zet_br, NN_sh, b_shock, root)

l_predict = exp(root);

%Effect of Experiment

[l_base l_predict];

scatter(getcolumn(ans(1:length(l),1:2),1),getcolumn(ans(1:length(l),1:2),2),'DisplayName','ans(1:length(l),1:2)(:,2) vs. ans(1:length(l),1:2)(:,1)','YDataSource','ans(1:length(l),1:2)(:,2)');figure(gcf)

median(exp(l)-1)
median(exp(l_base)-1)
median(exp(l_predict)-1)

Delta_l=median(exp(l)-1)*(1+((median(exp(l_predict)-1) - median(exp(l_base)-1))./median(exp(l_base)-1)))

disp('percent change in l')
disp(100*((median(exp(l_predict)-1) - median(exp(l_base)-1))./median(exp(l_base)-1)))


%Prosperity Outcomes
%Baseline
if sigma_sh==1
    s_base = (l_base.^alpha_sh).*((tau_sh*(b)).^(1-alpha_sh));
else
    s_base = ( (alpha_sh.*(l_base.^((sigma_sh-1)/sigma_sh))) + ((1-alpha_sh).*((tau_sh*(b)).^((sigma_sh-1)/sigma_sh))) ).^(sigma_sh/(sigma_sh-1));
end

p_base=zeros(n,num_out);
p_base_level=zeros(n,num_out);
for zz=1:num_out
    p_base(:,zz) = ( (theta_sh./alpha_sh).*l_base.*s_base.*((l_base./s_base).^(1/sigma_sh)) ) + (psi_2(zz).*(NN_sh*s_base)) + ([zscore(X) pop]*beta_out(((zz-1)*k)+zz:zz*(k+1))) + (X_d*zet_out((1+((zz*ndep)-ndep):zz*ndep)));
    p_base_level(:,zz) =((std(p(:,zz))*p_base(:,zz)) + mean(p(:,zz)));
end


if sigma_sh==1
    s_predict = (l_predict.^alpha_sh).*((tau_sh*(b + b_shock)).^(1-alpha_sh));
else
    s_predict = ( (alpha_sh.*(l_predict.^((sigma_sh-1)/sigma_sh))) + ((1-alpha_sh).*((tau_sh*(b + b_shock)).^((sigma_sh-1)/sigma_sh))) ).^(sigma_sh/(sigma_sh-1));
end

p_predict=zeros(n,num_out);
p_predict_level=zeros(n,num_out);
for zz=1:num_out
    p_predict(:,zz) = ( (theta_sh./alpha_sh).*l_predict.*s_predict.*((l_predict./s_predict).^(1/sigma_sh)) ) + (psi_2(zz).*(NN_sh*s_predict)) + ([zscore(X) pop]*beta_out(((zz-1)*k)+zz:zz*(k+1))) + (X_d*zet_out((1+((zz*ndep)-ndep):zz*ndep)));
    p_predict_level(:,zz) = ((std(p(:,zz))*p_predict(:,zz)) + mean(p(:,zz)));
end


Delta_p=zeros(1,num_out);
for zz=1:num_out
    Delta_p(1,zz) = ((median(p_predict_level(:,zz)) - median(p_base_level(:,zz)))./median(p_base_level(:,zz)));
end

p_experiment=zeros(1,num_out);

for zz=1:num_out
    p_experiment(1,zz) = (1+Delta_p(1,zz)).*median(p(:,zz));
end

disp('Observed median prosperity')
disp(median(p))
disp('Counterfactual median prosperity')
disp(p_experiment)



%Experiment: Take below-median local state capacity to median
l_0 = max(median(l),l);

%Shock to national state capacity
b_shock = b;

%Shock to weight of local state
alpha_sh = alpha;

%Shock to elasticity of substitution
sigma_sh = sigma ;

%Shock to marginal cost of local state
theta_sh = theta;

%Shock to interaction effect
psi_1_sh = psi_1;

%Shock to elasticity of national state tau
tau_sh = tau;

%Shock to "infrastructure"
delta_sh = 1*delta;
NN_sh = neighbors_matrix(delta_sh, order);

    Avg_nij_pr = NN_sh(:);
    Avg_nij_pr =  mean(Avg_nij_pr(Avg_nij_pr~=0))

    Avg_nij_pr*mean(l)*psi_1 + Avg_nij_pr*psi_2(1)  

    
%General Equilibrium Effect
BR(alpha_sh, sigma_sh, theta_sh, psi_1_sh, tau_sh, exp_cond_g, zet_br, NN_sh, b_shock, log(l_0))

f = @(x) BR(alpha_sh, sigma_sh, theta_sh, psi_1_sh, tau_sh, exp_cond_g, zet_br, NN_sh, b_shock, x) ; % function of dummy variable x

options = optimset('Display','iter', 'MaxFunEvals', 1000000, 'MaxIter', 1000);
[root, fval] = fsolve(f, log(l_0), options);

BR(alpha_sh, sigma_sh, theta_sh, psi_1_sh, tau_sh, exp_cond_g, zet_br, NN_sh, b_shock, root)

l_predict = exp(root);

%Effect of Experiment

[l_base l_predict l_predict./l_base];

scatter(getcolumn(ans(1:length(l),1:2),1),getcolumn(ans(1:length(l),1:2),2),'DisplayName','ans(1:length(l),1:2)(:,2) vs. ans(1:length(l),1:2)(:,1)','YDataSource','ans(1:length(l),1:2)(:,2)');figure(gcf)

median(exp(l)-1)
median(exp(l_base)-1)
median(exp(l_predict)-1)

Delta_l=median(exp(l)-1)*(1+((median(exp(l_predict)-1) - median(exp(l_base)-1))./median(exp(l_base)-1)))

disp('percent change in l')
disp(100*((median(exp(l_predict)-1) - median(exp(l_base)-1))./median(exp(l_base)-1)))


%Prosperity Outcomes
%Baseline
if sigma_sh==1
    s_base = (l_base.^alpha_sh).*((tau_sh*(b)).^(1-alpha_sh));
else
    s_base = ( (alpha_sh.*(l_base.^((sigma_sh-1)/sigma_sh))) + ((1-alpha_sh).*((tau_sh*(b)).^((sigma_sh-1)/sigma_sh))) ).^(sigma_sh/(sigma_sh-1));
end

p_base=zeros(n,num_out);
p_base_level=zeros(n,num_out);
for zz=1:num_out
    p_base(:,zz) = ( (theta_sh./alpha_sh).*l_base.*s_base.*((l_base./s_base).^(1/sigma_sh)) ) + (psi_2(zz).*(NN_sh*s_base)) + ([zscore(X) pop]*beta_out(((zz-1)*k)+zz:zz*(k+1))) + (X_d*zet_out((1+((zz*ndep)-ndep):zz*ndep)));
    p_base_level(:,zz) =((std(p(:,zz))*p_base(:,zz)) + mean(p(:,zz)));
end


if sigma_sh==1
    s_predict = (l_predict.^alpha_sh).*((tau_sh*(b + b_shock)).^(1-alpha_sh));
else
    s_predict = ( (alpha_sh.*(l_predict.^((sigma_sh-1)/sigma_sh))) + ((1-alpha_sh).*((tau_sh*(b + b_shock)).^((sigma_sh-1)/sigma_sh))) ).^(sigma_sh/(sigma_sh-1));
end

p_predict=zeros(n,num_out);
p_predict_level=zeros(n,num_out);
for zz=1:num_out
    p_predict(:,zz) = ( (theta_sh./alpha_sh).*l_predict.*s_predict.*((l_predict./s_predict).^(1/sigma_sh)) ) + (psi_2(zz).*(NN_sh*s_predict)) + ([zscore(X) pop]*beta_out(((zz-1)*k)+zz:zz*(k+1))) + (X_d*zet_out((1+((zz*ndep)-ndep):zz*ndep)));
    p_predict_level(:,zz) = ((std(p(:,zz))*p_predict(:,zz)) + mean(p(:,zz)));
end


Delta_p_median=zeros(1,num_out);
for zz=1:num_out
    Delta_p_median(1,zz) = ((median(p_predict_level(:,zz)) - median(p_base_level(:,zz)))./median(p_base_level(:,zz)));
end

p_experiment=zeros(1,num_out);
for zz=1:num_out
    p_experiment(1,zz) = (1+Delta_p_median(1,zz)).*median(p(:,zz));
end


disp('Observed median prosperity')
disp(median(p))
disp('Counterfactual median prosperity')
disp(p_experiment)



    %Direct Effect    
if sigma_sh==1
    s_direct = (l_0.^alpha_sh).*((tau_sh*(b)).^(1-alpha_sh));
else
    s_direct = ( (alpha_sh.*(l_0.^((sigma_sh-1)/sigma_sh))) + ((1-alpha_sh).*((tau_sh*(b)).^((sigma_sh-1)/sigma_sh))) ).^(sigma_sh/(sigma_sh-1));
end
 

p_direct=zeros(n,num_out);
p_direct_level=zeros(n,num_out);
for zz=1:num_out
    p_direct(:,zz) = ( (theta_sh./alpha_sh).*l_0.*s_direct.*((l_0./s_direct).^(1/sigma_sh)) ) + (psi_2(zz).*(NN_sh*s_direct)) + ([zscore(X) pop]*beta_out(((zz-1)*k)+zz:zz*(k+1))) + (X_d*zet_out((1+((zz*ndep)-ndep):zz*ndep)));
    p_direct_level(:,zz) =((std(p(:,zz))*p_direct(:,zz)) + mean(p(:,zz)));
end

Delta_p_direct=zeros(1,num_out);
for zz=1:num_out
    Delta_p_direct(1,zz) = ((median(p_direct_level(:,zz)) - median(p_base_level(:,zz)))./median(p_base_level(:,zz)));
end

p_direct_med=zeros(1,num_out);
for zz=1:num_out
    p_direct_med(1,zz) = (1+Delta_p_direct(1,zz)).*median(p(:,zz));
end

disp('Observed median prosperity')
disp(median(p))
disp('Counterfactual direct effect median prosperity')
disp(p_direct_med)








































